import _defineProperty from '@babel/runtime/helpers/defineProperty';
import 'core-js/modules/es.symbol.js';
import 'core-js/modules/es.array.concat.js';
import 'core-js/modules/es.array.filter.js';
import 'core-js/modules/es.number.parse-int.js';
import 'core-js/modules/es.object.get-own-property-descriptor.js';
import 'core-js/modules/es.object.get-own-property-descriptors.js';
import 'core-js/modules/es.object.keys.js';
import 'core-js/modules/es.object.to-string.js';
import 'core-js/modules/web.dom-collections.for-each.js';
import React__default from 'react';
import PropTypes from 'prop-types';
import { TextInput, Toggle } from '@carbon/react';
import { settings } from '../../../../../constants/Settings.js';

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var iotPrefix = settings.iotPrefix;
var propTypes = {
  /** card data value */
  cardConfig: PropTypes.shape({
    id: PropTypes.string,
    title: PropTypes.string,
    size: PropTypes.string,
    type: PropTypes.string,
    content: PropTypes.shape({
      series: PropTypes.arrayOf(PropTypes.shape({
        label: PropTypes.string,
        dataSourceId: PropTypes.string,
        color: PropTypes.string
      })),
      decimalPrecision: PropTypes.number,
      xLabel: PropTypes.string,
      yLabel: PropTypes.string,
      unit: PropTypes.string,
      includeZeroOnXaxis: PropTypes.bool,
      includeZeroOnYaxis: PropTypes.bool,
      timeDataSourceId: PropTypes.string,
      showLegend: PropTypes.bool,
      /**
       * maximum amounts of data points to render in the graph
       * The data point limitation doesn't actually affect the cards themselves. It is only stored
       * in the JSON and up to the downstream consumers to use when they fetch their data.
       */
      maximumDataPoints: PropTypes.number
    }),
    interval: PropTypes.string
  }),
  /** Callback function when form data changes */
  onChange: PropTypes.func.isRequired,
  i18n: PropTypes.shape({
    xAxisLabel: PropTypes.string,
    yAxisLabel: PropTypes.string,
    unitLabel: PropTypes.string,
    decimalPrecisionLabel: PropTypes.string,
    maximumDataPointsLabel: PropTypes.string
  })
};
var defaultProps = {
  cardConfig: {},
  i18n: {
    xAxisLabel: 'X-axis label',
    yAxisLabel: 'Y-axis label',
    includeZeroOnXaxis: 'Include zero on x-axis',
    includeZeroOnYaxis: 'Include zero on y-axis',
    unitLabel: 'Unit',
    decimalPrecisionLabel: 'Decimal precision',
    maximumDataPoints: 'Maximum data points'
  }
};
var DataSeriesFormSettings = function DataSeriesFormSettings(_ref) {
  var _content$xLabel, _content$yLabel, _content$unit, _cardConfig$content, _cardConfig$content2;
  var cardConfig = _ref.cardConfig,
    _onChange = _ref.onChange,
    i18n = _ref.i18n;
  var mergedI18n = _objectSpread(_objectSpread({}, defaultProps.i18n), i18n);
  var content = cardConfig.content,
    id = cardConfig.id;
  var baseClassName = "".concat(iotPrefix, "--card-edit-form");
  return /*#__PURE__*/React__default.createElement(React__default.Fragment, null, /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(baseClassName, "--input")
  }, /*#__PURE__*/React__default.createElement(TextInput, {
    id: "".concat(id, "_title"),
    labelText: mergedI18n.xAxisLabel,
    light: true,
    onChange: function onChange(evt) {
      return _onChange(_objectSpread(_objectSpread({}, cardConfig), {}, {
        content: _objectSpread(_objectSpread({}, cardConfig.content), {}, {
          xLabel: evt.target.value
        })
      }));
    },
    value: (_content$xLabel = content === null || content === void 0 ? void 0 : content.xLabel) !== null && _content$xLabel !== void 0 ? _content$xLabel : ''
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(baseClassName, "--input")
  }, /*#__PURE__*/React__default.createElement(TextInput, {
    id: "".concat(id, "_y-axis-label"),
    labelText: mergedI18n.yAxisLabel,
    light: true,
    onChange: function onChange(evt) {
      return _onChange(_objectSpread(_objectSpread({}, cardConfig), {}, {
        content: _objectSpread(_objectSpread({}, cardConfig.content), {}, {
          yLabel: evt.target.value
        })
      }));
    },
    value: (_content$yLabel = content === null || content === void 0 ? void 0 : content.yLabel) !== null && _content$yLabel !== void 0 ? _content$yLabel : ''
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(baseClassName, "--input")
  }, /*#__PURE__*/React__default.createElement(TextInput, {
    id: "".concat(id, "_unit-selection"),
    labelText: mergedI18n.unitLabel,
    light: true,
    onChange: function onChange(evt) {
      return _onChange(_objectSpread(_objectSpread({}, cardConfig), {}, {
        content: _objectSpread(_objectSpread({}, cardConfig.content), {}, {
          unit: evt.target.value
        })
      }));
    },
    value: (_content$unit = content === null || content === void 0 ? void 0 : content.unit) !== null && _content$unit !== void 0 ? _content$unit : ''
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(baseClassName, "--input")
  }, /*#__PURE__*/React__default.createElement(TextInput, {
    id: "".concat(id, "_decimal-precision"),
    labelText: mergedI18n.decimalPrecisionLabel,
    light: true,
    type: "number",
    onChange: function onChange(evt) {
      return _onChange(_objectSpread(_objectSpread({}, cardConfig), {}, {
        content: _objectSpread(_objectSpread({}, cardConfig.content), {}, {
          decimalPrecision: evt.target.value
        })
      }));
    },
    value: content === null || content === void 0 ? void 0 : content.decimalPrecision
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(baseClassName, "--input")
  }, /*#__PURE__*/React__default.createElement(TextInput, {
    id: "".concat(id, "_maximum_data_points"),
    labelText: mergedI18n.maximumDataPoints,
    light: true,
    type: "number",
    onChange: function onChange(evt) {
      var maximumDataPointsString = evt.target.value;
      var maximumDataPoints = Number.parseInt(maximumDataPointsString, 10);
      _onChange(_objectSpread(_objectSpread({}, cardConfig), {}, {
        content: _objectSpread(_objectSpread({}, cardConfig.content), {}, {
          maximumDataPoints: maximumDataPoints
        })
      }));
    },
    value: content === null || content === void 0 ? void 0 : content.maximumDataPoints
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(baseClassName, "--input--toggle-field ").concat(baseClassName, "--input")
  }, /*#__PURE__*/React__default.createElement("span", null, mergedI18n.includeZeroOnXaxis), /*#__PURE__*/React__default.createElement(Toggle, {
    size: "sm",
    "data-testid": "includeZeroOnXaxis-toggle",
    id: "includeZeroOnXaxis-toggle",
    "aria-label": mergedI18n.includeZeroOnXaxis,
    labelA: "",
    labelB: "",
    toggled: (_cardConfig$content = cardConfig.content) === null || _cardConfig$content === void 0 ? void 0 : _cardConfig$content.includeZeroOnXaxis,
    onToggle: function onToggle(bool) {
      return _onChange(_objectSpread(_objectSpread({}, cardConfig), {}, {
        content: _objectSpread(_objectSpread({}, cardConfig.content), {}, {
          includeZeroOnXaxis: bool
        })
      }));
    }
  })), /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(baseClassName, "--input--toggle-field ").concat(baseClassName, "--input")
  }, /*#__PURE__*/React__default.createElement("span", null, mergedI18n.includeZeroOnYaxis), /*#__PURE__*/React__default.createElement(Toggle, {
    size: "sm",
    "data-testid": "includeZeroOnYaxis-toggle",
    id: "includeZeroOnYaxis-toggle",
    "aria-label": mergedI18n.includeZeroOnYaxis,
    labelA: "",
    labelB: "",
    toggled: (_cardConfig$content2 = cardConfig.content) === null || _cardConfig$content2 === void 0 ? void 0 : _cardConfig$content2.includeZeroOnYaxis,
    onToggle: function onToggle(bool) {
      return _onChange(_objectSpread(_objectSpread({}, cardConfig), {}, {
        content: _objectSpread(_objectSpread({}, cardConfig.content), {}, {
          includeZeroOnYaxis: bool
        })
      }));
    }
  })));
};
DataSeriesFormSettings.propTypes = propTypes;
DataSeriesFormSettings.defaultProps = defaultProps;
DataSeriesFormSettings.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "DataSeriesFormSettings",
  "props": {
    "cardConfig": {
      "defaultValue": {
        "value": "{}",
        "computed": false
      },
      "description": "card data value",
      "type": {
        "name": "shape",
        "value": {
          "id": {
            "name": "string",
            "required": false
          },
          "title": {
            "name": "string",
            "required": false
          },
          "size": {
            "name": "string",
            "required": false
          },
          "type": {
            "name": "string",
            "required": false
          },
          "content": {
            "name": "shape",
            "value": {
              "series": {
                "name": "arrayOf",
                "value": {
                  "name": "shape",
                  "value": {
                    "label": {
                      "name": "string",
                      "required": false
                    },
                    "dataSourceId": {
                      "name": "string",
                      "required": false
                    },
                    "color": {
                      "name": "string",
                      "required": false
                    }
                  }
                },
                "required": false
              },
              "decimalPrecision": {
                "name": "number",
                "required": false
              },
              "xLabel": {
                "name": "string",
                "required": false
              },
              "yLabel": {
                "name": "string",
                "required": false
              },
              "unit": {
                "name": "string",
                "required": false
              },
              "includeZeroOnXaxis": {
                "name": "bool",
                "required": false
              },
              "includeZeroOnYaxis": {
                "name": "bool",
                "required": false
              },
              "timeDataSourceId": {
                "name": "string",
                "required": false
              },
              "showLegend": {
                "name": "bool",
                "required": false
              },
              "maximumDataPoints": {
                "name": "number",
                "description": "maximum amounts of data points to render in the graph\nThe data point limitation doesn't actually affect the cards themselves. It is only stored\nin the JSON and up to the downstream consumers to use when they fetch their data.",
                "required": false
              }
            },
            "required": false
          },
          "interval": {
            "name": "string",
            "required": false
          }
        }
      },
      "required": false
    },
    "i18n": {
      "defaultValue": {
        "value": "{\n  xAxisLabel: 'X-axis label',\n  yAxisLabel: 'Y-axis label',\n  includeZeroOnXaxis: 'Include zero on x-axis',\n  includeZeroOnYaxis: 'Include zero on y-axis',\n  unitLabel: 'Unit',\n  decimalPrecisionLabel: 'Decimal precision',\n  maximumDataPoints: 'Maximum data points',\n}",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "shape",
        "value": {
          "xAxisLabel": {
            "name": "string",
            "required": false
          },
          "yAxisLabel": {
            "name": "string",
            "required": false
          },
          "unitLabel": {
            "name": "string",
            "required": false
          },
          "decimalPrecisionLabel": {
            "name": "string",
            "required": false
          },
          "maximumDataPointsLabel": {
            "name": "string",
            "required": false
          }
        }
      },
      "required": false
    },
    "onChange": {
      "description": "Callback function when form data changes",
      "type": {
        "name": "func"
      },
      "required": true
    }
  }
};
var DataSeriesFormSettings$1 = DataSeriesFormSettings;

export { DataSeriesFormSettings$1 as default };
