import _asyncToGenerator from '@babel/runtime/helpers/asyncToGenerator';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import isEmpty from '../../../node_modules/lodash-es/isEmpty.js';
import _regeneratorRuntime from '@babel/runtime/regenerator';
import 'core-js/modules/es.symbol.js';
import 'core-js/modules/es.array.filter.js';
import 'core-js/modules/es.array.find.js';
import 'core-js/modules/es.array.join.js';
import 'core-js/modules/es.array.map.js';
import 'core-js/modules/es.object.get-own-property-descriptor.js';
import 'core-js/modules/es.object.get-own-property-descriptors.js';
import 'core-js/modules/es.object.keys.js';
import 'core-js/modules/es.object.to-string.js';
import 'core-js/modules/web.dom-collections.for-each.js';
import React__default, { useState, useCallback } from 'react';
import PropTypes from 'prop-types';
import { MultiSelect } from '@carbon/react';
import DataSeriesFormItemModal from '../../CardEditor/CardEditForm/CardEditFormItems/DataSeriesFormItemModal.js';
import List from '../../List/List.js';
import Button from '../../Button/Button.js';
import { settings } from '../../../constants/Settings.js';
import deprecate from '../../../internal/deprecate.js';
import { DashboardEditorActionsPropTypes } from '../../DashboardEditor/editorUtils.js';
import { Edit } from '@carbon/icons-react';

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var iotPrefix = settings.iotPrefix;

/* istanbul ignore next */
var noop = function noop() {};
var propTypes = {
  /** The hotspot for which the data source settings should be changed. */
  hotspot: PropTypes.shape({
    content: PropTypes.shape({
      attributes: PropTypes.arrayOf(PropTypes.object)
    })
  }).isRequired,
  /** This prop is mainly needed since the HotspotEditorDataSourceTab internally makes
   * use of DataSeriesFormItemModal which has its API designed around the card config */
  cardConfig: PropTypes.shape({
    id: PropTypes.string,
    title: PropTypes.string,
    size: PropTypes.string,
    type: PropTypes.string,
    content: PropTypes.shape({
      alt: PropTypes.string,
      src: PropTypes.string,
      image: PropTypes.string,
      hideMinimap: PropTypes.bool,
      hideHotspots: PropTypes.bool,
      hideZoomControls: PropTypes.bool,
      id: PropTypes.string
    }),
    description: PropTypes.string,
    values: PropTypes.shape({
      hotspots: PropTypes.arrayOf(PropTypes.object)
    })
  }).isRequired,
  i18n: PropTypes.shape({
    selectDataItemsText: PropTypes.string,
    dataItemText: PropTypes.string,
    editText: PropTypes.string,
    dataItemEditorDataItemTitle: PropTypes.string,
    dataItemEditorDataItemCustomLabel: PropTypes.string,
    dataItemEditorDataItemUnit: PropTypes.string,
    dataItemEditorDataItemFilter: PropTypes.string,
    dataItemEditorDataItemThresholds: PropTypes.string,
    dataItemEditorDataItemAddThreshold: PropTypes.string,
    primaryButtonLabelText: PropTypes.string,
    secondaryButtonLabelText: PropTypes.string
  }),
  /** Callback i18n function for translating ListBoxMenuIcon SVG title in the MultiSelect component */
  translateWithId: PropTypes.func.isRequired,
  /** callback when image input value changes */
  onChange: PropTypes.func.isRequired,
  // eslint-disable-next-line react/require-default-props
  testID: deprecate(PropTypes.string, "The 'testID' prop has been deprecated. Please use 'testId' instead."),
  /** Id that can be used for testing */
  testId: PropTypes.string,
  /** An array of data source items that can be selected for the specified hotspot */
  dataItems: PropTypes.arrayOf(PropTypes.shape({
    dataSourceId: PropTypes.string,
    label: PropTypes.string
  })),
  /** An object where the keys are available dimensions and the values are the values available for those dimensions
   *  ex: { manufacturer: ['Rentech', 'GHI Industries'], deviceid: ['73000', '73001', '73002'] } */
  availableDimensions: PropTypes.shape({}),
  actions: DashboardEditorActionsPropTypes
};
var defaultProps = {
  i18n: {
    selectDataItemsText: 'Select data items',
    dataItemText: 'Data items',
    editText: 'Edit',
    dataItemEditorDataItemTitle: 'Data items',
    dataItemEditorDataItemCustomLabel: 'Custom label',
    dataItemEditorDataItemUnit: 'Unit',
    dataItemEditorDataItemFilter: 'Data filter',
    dataItemEditorDataItemThresholds: 'Thresholds',
    dataItemEditorDataItemAddThreshold: 'Add threshold',
    primaryButtonLabelText: 'Update',
    secondaryButtonLabelText: 'Cancel'
  },
  dataItems: [],
  availableDimensions: {},
  testId: 'HotspotEditorDataSourceTab',
  actions: {
    onEditDataItem: noop,
    dataSeriesFormActions: {
      hasAggregationsDropDown: noop,
      hasDataFilterDropdown: noop,
      onAddAggregations: noop
    }
  }
};
var formatDataItemsForDropdown = function formatDataItemsForDropdown(dataItems) {
  return dataItems === null || dataItems === void 0 ? void 0 : dataItems.map(function (_ref) {
    var dataSourceId = _ref.dataSourceId,
      label = _ref.label;
    return {
      id: dataSourceId,
      label: label
    };
  });
};
var HotspotEditorDataSourceTab = function HotspotEditorDataSourceTab(_ref2) {
  var _hotspot$content;
  var hotspot = _ref2.hotspot,
    cardConfig = _ref2.cardConfig,
    dataItems = _ref2.dataItems,
    i18n = _ref2.i18n,
    onChange = _ref2.onChange,
    availableDimensions = _ref2.availableDimensions,
    testID = _ref2.testID,
    testId = _ref2.testId,
    translateWithId = _ref2.translateWithId,
    actions = _ref2.actions;
  var mergedI18n = _objectSpread(_objectSpread({}, defaultProps.i18n), i18n);
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    showEditor = _useState2[0],
    setShowEditor = _useState2[1];
  var _useState3 = useState({}),
    _useState4 = _slicedToArray(_useState3, 2),
    editDataItem = _useState4[0],
    setEditDataItem = _useState4[1];
  var selectedItemsArray = ((_hotspot$content = hotspot.content) === null || _hotspot$content === void 0 ? void 0 : _hotspot$content.attributes) || [];
  var baseClassName = "".concat(iotPrefix, "--card-edit-form");
  var initialSelectedItems = formatDataItemsForDropdown(selectedItemsArray);
  var onEditDataItem = actions.onEditDataItem;
  var handleSelectionChange = function handleSelectionChange(_ref3) {
    var selectedItems = _ref3.selectedItems;
    var newArray = [];
    // loop through  selected Items and find their selectedItemsArray object or the dataItem object with same id
    selectedItems.forEach(function (item) {
      var containedItem = selectedItemsArray.find(function (selectedItem) {
        return selectedItem.dataItemId === item.id;
      });
      var containedDataItem = dataItems.find(function (selectedItem) {
        return selectedItem.dataItemId === item.id;
      });
      if (containedItem) {
        newArray.push(containedItem);
      } else if (containedDataItem) {
        newArray.push(containedDataItem);
      }
    });
    onChange({
      attributes: newArray
    });
  };

  // MultiSelect
  // For the initial selection to work the objects in prop "initialSelectedItems"
  // must be identical to the objects in prop "items". It is not enough that the
  // ids are the same. Therefore, we must adjust the labels in "items" if they have
  // been modified in the "initialSelectedItems".
  var multiSelectItems = formatDataItemsForDropdown(dataItems).map(function (item) {
    var _initialSelectedItems, _initialSelectedItems2;
    return _objectSpread(_objectSpread({}, item), {}, {
      label: (_initialSelectedItems = (_initialSelectedItems2 = initialSelectedItems.find(function (selected) {
        return selected.id === item.id;
      })) === null || _initialSelectedItems2 === void 0 ? void 0 : _initialSelectedItems2.label) !== null && _initialSelectedItems !== void 0 ? _initialSelectedItems : item.label
    });
  });
  var handleEditButton = useCallback(/*#__PURE__*/function () {
    var _ref4 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(dataItem) {
      var dataItemWithMetaData, aggregationMethods;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            dataItemWithMetaData = dataItems === null || dataItems === void 0 ? void 0 : dataItems.find(function (_ref5) {
              var dataItemId = _ref5.dataItemId;
              return dataItemId === dataItem.dataSourceId;
            }); // Call back function for on click of edit button
            /* istanbul ignore else */
            if (!onEditDataItem) {
              _context.next = 6;
              break;
            }
            _context.next = 4;
            return onEditDataItem(cardConfig, dataItem, dataItemWithMetaData);
          case 4:
            aggregationMethods = _context.sent;
            if (!isEmpty(aggregationMethods)) {
              dataItemWithMetaData.aggregationMethods = aggregationMethods;
            }
          case 6:
            // need to reset the card to include the latest dataSection
            setEditDataItem(_objectSpread(_objectSpread({}, dataItemWithMetaData), dataItem));
            setShowEditor(true);
          case 8:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function (_x) {
      return _ref4.apply(this, arguments);
    };
  }(), [cardConfig, onEditDataItem, dataItems]);
  return /*#__PURE__*/React__default.createElement("div", {
    "data-testid": testID || testId
  }, /*#__PURE__*/React__default.createElement(DataSeriesFormItemModal, {
    isLarge: true,
    cardConfig: cardConfig,
    showEditor: showEditor,
    setShowEditor: setShowEditor,
    editDataItem: editDataItem,
    setEditDataItem: setEditDataItem,
    setEditDataSeries: setEditDataItem,
    availableDimensions: availableDimensions,
    onChange: onChange,
    i18n: mergedI18n,
    actions: actions,
    options: {
      hasColorDropdown: false,
      hasUnit: true,
      hasDecimalPlacesDropdown: true,
      hasThresholds: true,
      hasTooltip: false
    }
  }), /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(baseClassName, "--input")
  }, /*#__PURE__*/React__default.createElement(MultiSelect
  // need to re-gen if multiSelectItems changes (i.e. the label)
  , {
    key: "".concat(multiSelectItems.map(function (item) {
      return item.label;
    }).join('')),
    id: "".concat(cardConfig.id, "_dataSourceIds"),
    label: mergedI18n.selectDataItemsText,
    direction: "bottom",
    initialSelectedItems: initialSelectedItems,
    items: multiSelectItems,
    light: true,
    onChange: handleSelectionChange,
    titleText: mergedI18n.dataItemText,
    translateWithId: translateWithId,
    "data-testid": "".concat(testId, "-multiselect")
  })), /*#__PURE__*/React__default.createElement(List
  // need to force an empty "empty state"
  , {
    emptyState: /*#__PURE__*/React__default.createElement("div", null),
    testId: "".concat(testId, "-data-source-list"),
    title: "",
    items: selectedItemsArray === null || selectedItemsArray === void 0 ? void 0 : selectedItemsArray.map(function (dataItem) {
      return {
        id: dataItem.dataSourceId,
        content: {
          value: dataItem.label,
          rowActions: function rowActions() {
            return [/*#__PURE__*/React__default.createElement(Button, {
              key: "data-item-".concat(dataItem.dataSourceId),
              renderIcon: Edit,
              hasIconOnly: true,
              kind: "ghost",
              size: "sm",
              onClick: function onClick() {
                return handleEditButton(dataItem);
              },
              iconDescription: mergedI18n.editText
            })];
          }
        }
      };
    })
  }));
};
HotspotEditorDataSourceTab.propTypes = propTypes;
HotspotEditorDataSourceTab.defaultProps = defaultProps;
HotspotEditorDataSourceTab.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "HotspotEditorDataSourceTab",
  "props": {
    "i18n": {
      "defaultValue": {
        "value": "{\n  selectDataItemsText: 'Select data items',\n  dataItemText: 'Data items',\n  editText: 'Edit',\n  dataItemEditorDataItemTitle: 'Data items',\n  dataItemEditorDataItemCustomLabel: 'Custom label',\n  dataItemEditorDataItemUnit: 'Unit',\n  dataItemEditorDataItemFilter: 'Data filter',\n  dataItemEditorDataItemThresholds: 'Thresholds',\n  dataItemEditorDataItemAddThreshold: 'Add threshold',\n  primaryButtonLabelText: 'Update',\n  secondaryButtonLabelText: 'Cancel',\n}",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "shape",
        "value": {
          "selectDataItemsText": {
            "name": "string",
            "required": false
          },
          "dataItemText": {
            "name": "string",
            "required": false
          },
          "editText": {
            "name": "string",
            "required": false
          },
          "dataItemEditorDataItemTitle": {
            "name": "string",
            "required": false
          },
          "dataItemEditorDataItemCustomLabel": {
            "name": "string",
            "required": false
          },
          "dataItemEditorDataItemUnit": {
            "name": "string",
            "required": false
          },
          "dataItemEditorDataItemFilter": {
            "name": "string",
            "required": false
          },
          "dataItemEditorDataItemThresholds": {
            "name": "string",
            "required": false
          },
          "dataItemEditorDataItemAddThreshold": {
            "name": "string",
            "required": false
          },
          "primaryButtonLabelText": {
            "name": "string",
            "required": false
          },
          "secondaryButtonLabelText": {
            "name": "string",
            "required": false
          }
        }
      },
      "required": false
    },
    "dataItems": {
      "defaultValue": {
        "value": "[]",
        "computed": false
      },
      "description": "An array of data source items that can be selected for the specified hotspot",
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "shape",
          "value": {
            "dataSourceId": {
              "name": "string",
              "required": false
            },
            "label": {
              "name": "string",
              "required": false
            }
          }
        }
      },
      "required": false
    },
    "availableDimensions": {
      "defaultValue": {
        "value": "{}",
        "computed": false
      },
      "description": "An object where the keys are available dimensions and the values are the values available for those dimensions\n ex: { manufacturer: ['Rentech', 'GHI Industries'], deviceid: ['73000', '73001', '73002'] }",
      "type": {
        "name": "shape",
        "value": {}
      },
      "required": false
    },
    "testId": {
      "defaultValue": {
        "value": "'HotspotEditorDataSourceTab'",
        "computed": false
      },
      "description": "Id that can be used for testing",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "actions": {
      "defaultValue": {
        "value": "{\n  onEditDataItem: noop,\n  dataSeriesFormActions: {\n    hasAggregationsDropDown: noop,\n    hasDataFilterDropdown: noop,\n    onAddAggregations: noop,\n  },\n}",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "custom",
        "raw": "DashboardEditorActionsPropTypes"
      },
      "required": false
    },
    "hotspot": {
      "description": "The hotspot for which the data source settings should be changed.",
      "type": {
        "name": "shape",
        "value": {
          "content": {
            "name": "shape",
            "value": {
              "attributes": {
                "name": "arrayOf",
                "value": {
                  "name": "object"
                },
                "required": false
              }
            },
            "required": false
          }
        }
      },
      "required": true
    },
    "cardConfig": {
      "description": "This prop is mainly needed since the HotspotEditorDataSourceTab internally makes\nuse of DataSeriesFormItemModal which has its API designed around the card config",
      "type": {
        "name": "shape",
        "value": {
          "id": {
            "name": "string",
            "required": false
          },
          "title": {
            "name": "string",
            "required": false
          },
          "size": {
            "name": "string",
            "required": false
          },
          "type": {
            "name": "string",
            "required": false
          },
          "content": {
            "name": "shape",
            "value": {
              "alt": {
                "name": "string",
                "required": false
              },
              "src": {
                "name": "string",
                "required": false
              },
              "image": {
                "name": "string",
                "required": false
              },
              "hideMinimap": {
                "name": "bool",
                "required": false
              },
              "hideHotspots": {
                "name": "bool",
                "required": false
              },
              "hideZoomControls": {
                "name": "bool",
                "required": false
              },
              "id": {
                "name": "string",
                "required": false
              }
            },
            "required": false
          },
          "description": {
            "name": "string",
            "required": false
          },
          "values": {
            "name": "shape",
            "value": {
              "hotspots": {
                "name": "arrayOf",
                "value": {
                  "name": "object"
                },
                "required": false
              }
            },
            "required": false
          }
        }
      },
      "required": true
    },
    "translateWithId": {
      "description": "Callback i18n function for translating ListBoxMenuIcon SVG title in the MultiSelect component",
      "type": {
        "name": "func"
      },
      "required": true
    },
    "onChange": {
      "description": "callback when image input value changes",
      "type": {
        "name": "func"
      },
      "required": true
    },
    "testID": {
      "description": "",
      "type": {
        "name": "custom",
        "raw": "deprecate(\n  PropTypes.string,\n  `The 'testID' prop has been deprecated. Please use 'testId' instead.`\n)"
      },
      "required": false
    }
  }
};
var HotspotEditorDataSourceTab$1 = HotspotEditorDataSourceTab;

export { HotspotEditorDataSourceTab$1 as default, formatDataItemsForDropdown };
