import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import _asyncToGenerator from '@babel/runtime/helpers/asyncToGenerator';
import 'core-js/modules/es.symbol.js';
import 'core-js/modules/es.array.concat.js';
import 'core-js/modules/es.array.filter.js';
import 'core-js/modules/es.array.find.js';
import 'core-js/modules/es.array.map.js';
import 'core-js/modules/es.function.name.js';
import 'core-js/modules/es.object.get-own-property-descriptor.js';
import 'core-js/modules/es.object.get-own-property-descriptors.js';
import 'core-js/modules/es.object.keys.js';
import 'core-js/modules/es.object.to-string.js';
import 'core-js/modules/web.dom-collections.for-each.js';
import _regeneratorRuntime from '@babel/runtime/regenerator';
import React__default, { useState, useEffect, useCallback } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { SideNavLink, SideNavDivider } from '@carbon/react';
import { settings } from '../../../constants/Settings.js';
import { shouldOpenInNewWindow } from '../suiteHeaderUtils.js';
import { SUITE_HEADER_ROUTE_TYPES } from '../suiteHeaderConstants.js';
import { SuiteHeaderApplicationPropTypes, SuiteHeaderWorkspacePropTypes } from '../SuiteHeaderPropTypes.js';
import { handleSpecificKeyDown } from '../../../utils/componentUtilityFunctions.js';
import { Launch, ChevronRight, Grid, Bee, ChevronLeft } from '@carbon/icons-react';

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var defaultProps = {
  customApplications: [],
  globalApplications: [],
  onRouteChange: function () {
    var _onRouteChange = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            return _context.abrupt("return", true);
          case 1:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    function onRouteChange() {
      return _onRouteChange.apply(this, arguments);
    }
    return onRouteChange;
  }(),
  i18n: {
    workspace: 'Workspace',
    workspaces: 'Workspaces',
    workspaceAdmin: 'Workspace administration',
    backToAppSwitcher: 'Back to applications',
    selectWorkspace: 'Select a workspace',
    availableWorkspaces: 'Available workspaces',
    suiteAdmin: 'Suite administration',
    global: 'Global / other',
    allApplicationsLink: 'All applications',
    requestAccess: 'Contact your administrator to request application access.',
    learnMoreLink: 'Learn more'
  },
  testId: 'multi-workspace-suite-header-app-switcher',
  isExpanded: false,
  workspaces: null,
  noAccessLink: null,
  adminLink: null,
  isAdminView: false
};
var propTypes = {
  customApplications: PropTypes.arrayOf(PropTypes.shape(SuiteHeaderApplicationPropTypes)),
  globalApplications: PropTypes.arrayOf(PropTypes.shape(SuiteHeaderApplicationPropTypes)),
  noAccessLink: PropTypes.string,
  onRouteChange: PropTypes.func,
  i18n: PropTypes.shape({
    workspace: PropTypes.string,
    workspaces: PropTypes.string,
    workspaceAdmin: PropTypes.string,
    backToAppSwitcher: PropTypes.string,
    selectWorkspace: PropTypes.string,
    availableWorkspaces: PropTypes.string,
    suiteAdmin: PropTypes.string,
    allApplicationsLink: PropTypes.string,
    requestAccess: PropTypes.string,
    learnMoreLink: PropTypes.string
  }),
  testId: PropTypes.string,
  isExpanded: PropTypes.bool,
  workspaces: PropTypes.arrayOf(PropTypes.shape(SuiteHeaderWorkspacePropTypes)),
  adminLink: PropTypes.string,
  isAdminView: PropTypes.bool
};
var MultiWorkspaceSuiteHeaderAppSwitcher = function MultiWorkspaceSuiteHeaderAppSwitcher(_ref) {
  var _selectedWorkspace$ap, _ref9, _selectedWorkspace$na;
  var customApplications = _ref.customApplications,
    globalApplications = _ref.globalApplications,
    noAccessLink = _ref.noAccessLink,
    i18n = _ref.i18n,
    onRouteChange = _ref.onRouteChange,
    testId = _ref.testId,
    isExpanded = _ref.isExpanded,
    workspaces = _ref.workspaces,
    adminLink = _ref.adminLink,
    isAdminView = _ref.isAdminView;
  var _useState = useState(false),
    _useState2 = _slicedToArray(_useState, 2),
    isWorkspacesView = _useState2[0],
    setWorkspacesView = _useState2[1];
  var _useState3 = useState(null),
    _useState4 = _slicedToArray(_useState3, 2),
    selectedWorkspace = _useState4[0],
    setSelectedWorkspace = _useState4[1];
  var mergedI18n = _objectSpread(_objectSpread({}, defaultProps.i18n), i18n);
  var baseClassName = "".concat(settings.iotPrefix, "--suite-header-app-switcher-multiworkspace");
  var workspaceApplications = workspaces ? (_selectedWorkspace$ap = selectedWorkspace === null || selectedWorkspace === void 0 ? void 0 : selectedWorkspace.applications) !== null && _selectedWorkspace$ap !== void 0 ? _selectedWorkspace$ap : [] : null;
  var currentWorkspace = workspaces === null || workspaces === void 0 ? void 0 : workspaces.find(function (wo) {
    return wo.isCurrent;
  });
  useEffect(function () {
    // Show the workspace selection list if no workspace has been selected yet and if this is not a workspace-based page
    if (!isWorkspacesView && !selectedWorkspace && (workspaces === null || workspaces === void 0 ? void 0 : workspaces.length) > 1 && !currentWorkspace) {
      setWorkspacesView(true);
    }
  }, [isWorkspacesView, workspaces, selectedWorkspace, currentWorkspace]);
  useEffect(function () {
    if (!selectedWorkspace) {
      // If only 1 workspace is available, select it regardless of whether or not we are in a workspace-based page
      if ((workspaces === null || workspaces === void 0 ? void 0 : workspaces.length) === 1) {
        setSelectedWorkspace(workspaces[0]);
        setWorkspacesView(false);
      } else if (currentWorkspace) {
        // If there are more workspace, select the one with the isCurrent flag set
        setSelectedWorkspace(currentWorkspace);
        setWorkspacesView(false);
      }
    }
  }, [workspaces, currentWorkspace, selectedWorkspace, setSelectedWorkspace]);
  var handleRouteChange = useCallback(/*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee2(event, routeType, url) {
      var isExternal,
        data,
        newWindow,
        result,
        _args2 = arguments;
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) switch (_context2.prev = _context2.next) {
          case 0:
            isExternal = _args2.length > 3 && _args2[3] !== undefined ? _args2[3] : false;
            data = _args2.length > 4 && _args2[4] !== undefined ? _args2[4] : null;
            event.preventDefault();
            newWindow = shouldOpenInNewWindow(event);
            _context2.next = 6;
            return onRouteChange(routeType, url, data);
          case 6:
            result = _context2.sent;
            if (result) {
              if (isExternal || newWindow) {
                window.open(url, '_blank', 'noopener noreferrer');
              } else {
                window.location.href = url;
              }
            }
          case 8:
          case "end":
            return _context2.stop();
        }
      }, _callee2);
    }));
    return function (_x, _x2, _x3) {
      return _ref2.apply(this, arguments);
    };
  }(), [onRouteChange]);
  var handleApplicationRoute = useCallback(function (_ref3) {
    var id = _ref3.id,
      href = _ref3.href,
      isExternal = _ref3.isExternal;
    return /*#__PURE__*/function () {
      var _ref4 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee3(e) {
        return _regeneratorRuntime.wrap(function _callee3$(_context3) {
          while (1) switch (_context3.prev = _context3.next) {
            case 0:
              return _context3.abrupt("return", handleRouteChange(e, SUITE_HEADER_ROUTE_TYPES.APPLICATION, href, isExternal, {
                appId: id
              }));
            case 1:
            case "end":
              return _context3.stop();
          }
        }, _callee3);
      }));
      return function (_x4) {
        return _ref4.apply(this, arguments);
      };
    }();
  }, [handleRouteChange]);
  var handleWorkspaceRoute = useCallback(function (_ref5) {
    var id = _ref5.id,
      href = _ref5.href;
    return /*#__PURE__*/function () {
      var _ref6 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee4(e) {
        return _regeneratorRuntime.wrap(function _callee4$(_context4) {
          while (1) switch (_context4.prev = _context4.next) {
            case 0:
              return _context4.abrupt("return", handleRouteChange(e, SUITE_HEADER_ROUTE_TYPES.NAVIGATOR, href, false, {
                workspaceId: id
              }));
            case 1:
            case "end":
              return _context4.stop();
          }
        }, _callee4);
      }));
      return function (_x5) {
        return _ref6.apply(this, arguments);
      };
    }();
  }, [handleRouteChange]);
  var handleWorkspaceSelection = useCallback(function (workspace) {
    return /*#__PURE__*/function () {
      var _ref7 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee5(e) {
        var id, href;
        return _regeneratorRuntime.wrap(function _callee5$(_context5) {
          while (1) switch (_context5.prev = _context5.next) {
            case 0:
              id = workspace.id, href = workspace.href;
              if (currentWorkspace) {
                handleWorkspaceRoute({
                  id: id,
                  href: href
                })(e);
              } else {
                setSelectedWorkspace(workspace);
                setWorkspacesView(false);
              }
            case 2:
            case "end":
              return _context5.stop();
          }
        }, _callee5);
      }));
      return function (_x6) {
        return _ref7.apply(this, arguments);
      };
    }();
  }, [currentWorkspace, handleWorkspaceRoute]);
  var handleAdminRoute = useCallback(/*#__PURE__*/function () {
    var _ref8 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee6(e) {
      return _regeneratorRuntime.wrap(function _callee6$(_context6) {
        while (1) switch (_context6.prev = _context6.next) {
          case 0:
            return _context6.abrupt("return", handleRouteChange(e, SUITE_HEADER_ROUTE_TYPES.ADMIN, adminLink));
          case 1:
          case "end":
            return _context6.stop();
        }
      }, _callee6);
    }));
    return function (_x7) {
      return _ref8.apply(this, arguments);
    };
  }(), [adminLink, handleRouteChange]);
  var tabIndex = isExpanded ? 0 : -1;
  var renderNavItem = useCallback(function (name, href, isExternal, icon, eventHandler, isSelected, keySuffix) {
    return /*#__PURE__*/React__default.createElement(SideNavLink, {
      id: "".concat(testId, "--").concat(keySuffix),
      key: "".concat(testId, "--").concat(keySuffix),
      className: classnames("".concat(baseClassName, "--app-link"), _defineProperty(_defineProperty({}, "".concat(baseClassName, "--external"), isExternal), "".concat(baseClassName, "--no-icon"), !icon)),
      "data-testid": "".concat(testId, "--").concat(keySuffix),
      onClick: eventHandler,
      onKeyDown: handleSpecificKeyDown(['Enter', 'Space'], eventHandler),
      tabIndex: tabIndex,
      renderIcon: icon ? typeof icon === 'string' ? function () {
        return /*#__PURE__*/React__default.createElement("img", {
          src: "data:image/svg+xml;base64, ".concat(icon),
          alt: "appIcon"
        });
      } : icon : null,
      href: href,
      rel: "noopener noreferrer",
      large: true,
      isActive: isSelected,
      title: name
    }, name, isExternal ? /*#__PURE__*/React__default.createElement(Launch, null) : null);
  }, [baseClassName, tabIndex, testId]);
  var selectedWorkspaceLabel = (_ref9 = (_selectedWorkspace$na = selectedWorkspace === null || selectedWorkspace === void 0 ? void 0 : selectedWorkspace.name) !== null && _selectedWorkspace$na !== void 0 ? _selectedWorkspace$na : selectedWorkspace === null || selectedWorkspace === void 0 ? void 0 : selectedWorkspace.id) !== null && _ref9 !== void 0 ? _ref9 : mergedI18n.selectWorkspace;
  return /*#__PURE__*/React__default.createElement("ul", {
    "data-testid": testId,
    className: baseClassName,
    tabIndex: tabIndex
  }, !isWorkspacesView ? /*#__PURE__*/React__default.createElement(React__default.Fragment, null, (workspaces === null || workspaces === void 0 ? void 0 : workspaces.length) > 1 ? /*#__PURE__*/React__default.createElement(React__default.Fragment, null, /*#__PURE__*/React__default.createElement("p", null, mergedI18n.workspace), /*#__PURE__*/React__default.createElement(SideNavLink, {
    id: "".concat(testId, "--selected-workspace"),
    key: "".concat(testId, "--selected-workspace"),
    className: "".concat(baseClassName, "--app-link ").concat(baseClassName, "--workpsace-selector"),
    "data-testid": "".concat(testId, "--selected-workspace"),
    onClick: function onClick() {
      return setWorkspacesView(true);
    },
    onKeyDown: handleSpecificKeyDown(['Enter', 'Space'], function () {
      return setWorkspacesView(true);
    }),
    tabIndex: tabIndex,
    renderIcon: ChevronRight,
    large: true,
    title: selectedWorkspaceLabel
  }, selectedWorkspaceLabel), /*#__PURE__*/React__default.createElement(SideNavDivider, {
    className: "".concat(baseClassName, "--divider")
  })) : null, selectedWorkspace !== null && selectedWorkspace !== void 0 && selectedWorkspace.href ? renderNavItem(mergedI18n.allApplicationsLink, selectedWorkspace.href, false, Grid, handleWorkspaceRoute({
    id: selectedWorkspace.id,
    href: selectedWorkspace.href
  }), false, "all-applications") : null, workspaceApplications ? workspaceApplications === null || workspaceApplications === void 0 ? void 0 : workspaceApplications.map(function (_ref10) {
    var id = _ref10.id,
      name = _ref10.name,
      href = _ref10.href,
      _ref10$isExternal = _ref10.isExternal,
      isExternal = _ref10$isExternal === void 0 ? false : _ref10$isExternal,
      _ref10$icon = _ref10.icon,
      icon = _ref10$icon === void 0 ? null : _ref10$icon;
    return renderNavItem(name, href, isExternal, icon, handleApplicationRoute({
      id: id,
      href: href,
      isExternal: isExternal
    }), false, "application-".concat(id));
  }) : null, selectedWorkspace !== null && selectedWorkspace !== void 0 && selectedWorkspace.adminHref ? renderNavItem(mergedI18n.workspaceAdmin, selectedWorkspace.adminHref, false, null, handleWorkspaceRoute({
    id: selectedWorkspace.id,
    href: selectedWorkspace.adminHref
  }), false, "admin-workspace") : null, selectedWorkspace && (workspaceApplications === null || workspaceApplications === void 0 ? void 0 : workspaceApplications.length) === 0 ? /*#__PURE__*/React__default.createElement("div", {
    "data-testid": "".concat(testId, "--no-app"),
    className: "".concat(baseClassName, "--no-app")
  }, /*#__PURE__*/React__default.createElement("div", {
    className: "bee-icon-container"
  }, /*#__PURE__*/React__default.createElement(Bee, {
    size: 32
  }), /*#__PURE__*/React__default.createElement("div", {
    className: "bee-shadow"
  })), /*#__PURE__*/React__default.createElement("span", null, mergedI18n.requestAccess), /*#__PURE__*/React__default.createElement("a", {
    href: noAccessLink,
    rel: "noopener noreferrer",
    "data-testid": "".concat(testId, "--no-access"),
    onClick: (/*#__PURE__*/function () {
      var _ref11 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee7(e) {
        var result;
        return _regeneratorRuntime.wrap(function _callee7$(_context7) {
          while (1) switch (_context7.prev = _context7.next) {
            case 0:
              e.preventDefault();
              _context7.next = 3;
              return onRouteChange(SUITE_HEADER_ROUTE_TYPES.DOCUMENTATION, noAccessLink);
            case 3:
              result = _context7.sent;
              if (result) {
                window.location.href = noAccessLink;
              }
            case 5:
            case "end":
              return _context7.stop();
          }
        }, _callee7);
      }));
      return function (_x8) {
        return _ref11.apply(this, arguments);
      };
    }()),
    tabIndex: tabIndex
  }, mergedI18n.learnMoreLink)) : null) : /*#__PURE__*/React__default.createElement(React__default.Fragment, null, selectedWorkspace ? /*#__PURE__*/React__default.createElement(React__default.Fragment, null, /*#__PURE__*/React__default.createElement(SideNavLink, {
    id: "".concat(testId, "--back-to-switcher"),
    key: "".concat(testId, "--back-to-switcher"),
    className: "".concat(baseClassName, "--app-link"),
    "data-testid": "".concat(testId, "--back-to-switcher"),
    onClick: function onClick() {
      return setWorkspacesView(false);
    },
    onKeyDown: handleSpecificKeyDown(['Enter', 'Space'], function () {
      return setWorkspacesView(false);
    }),
    renderIcon: ChevronLeft,
    tabIndex: tabIndex,
    large: true,
    title: mergedI18n.backToAppSwitcher
  }, mergedI18n.backToAppSwitcher), /*#__PURE__*/React__default.createElement(SideNavDivider, {
    className: "".concat(baseClassName, "--divider")
  }), /*#__PURE__*/React__default.createElement("p", null, mergedI18n.availableWorkspaces)) : /*#__PURE__*/React__default.createElement("p", null, mergedI18n.selectWorkspace), workspaces.map(function (workspace) {
    var _workspace$name;
    return renderNavItem((_workspace$name = workspace.name) !== null && _workspace$name !== void 0 ? _workspace$name : workspace.id, currentWorkspace ? workspace.href : null, false, null, handleWorkspaceSelection(workspace), workspace.id === (selectedWorkspace === null || selectedWorkspace === void 0 ? void 0 : selectedWorkspace.id), "workspace-".concat(workspace.id));
  })), adminLink || (globalApplications === null || globalApplications === void 0 ? void 0 : globalApplications.length) > 0 ? /*#__PURE__*/React__default.createElement(React__default.Fragment, null, /*#__PURE__*/React__default.createElement(SideNavDivider, {
    className: "".concat(baseClassName, "--divider")
  }), /*#__PURE__*/React__default.createElement("p", null, mergedI18n.global)) : null, adminLink ? renderNavItem(mergedI18n.suiteAdmin, adminLink, false, null, handleAdminRoute, isAdminView, "admin") : null, globalApplications === null || globalApplications === void 0 ? void 0 : globalApplications.map(function (_ref12) {
    var id = _ref12.id,
      name = _ref12.name,
      href = _ref12.href,
      _ref12$isExternal = _ref12.isExternal,
      isExternal = _ref12$isExternal === void 0 ? false : _ref12$isExternal,
      _ref12$icon = _ref12.icon,
      icon = _ref12$icon === void 0 ? null : _ref12$icon;
    return renderNavItem(name, href, isExternal, icon, handleApplicationRoute({
      id: id,
      href: href,
      isExternal: isExternal
    }), false, "global-application-".concat(id));
  }), customApplications.length > 0 ? /*#__PURE__*/React__default.createElement(SideNavDivider, {
    className: "".concat(baseClassName, "--divider")
  }) : null, customApplications.map(function (_ref13) {
    var id = _ref13.id,
      name = _ref13.name,
      href = _ref13.href,
      _ref13$isExternal = _ref13.isExternal,
      isExternal = _ref13$isExternal === void 0 ? false : _ref13$isExternal,
      _ref13$icon = _ref13.icon,
      icon = _ref13$icon === void 0 ? null : _ref13$icon;
    return renderNavItem(name, href, isExternal, icon, handleApplicationRoute({
      id: id,
      href: href,
      isExternal: isExternal
    }), false, "custom-application-".concat(id));
  }));
};
MultiWorkspaceSuiteHeaderAppSwitcher.defaultProps = defaultProps;
MultiWorkspaceSuiteHeaderAppSwitcher.propTypes = propTypes;
MultiWorkspaceSuiteHeaderAppSwitcher.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "MultiWorkspaceSuiteHeaderAppSwitcher",
  "props": {
    "customApplications": {
      "defaultValue": {
        "value": "[]",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "shape",
          "value": "import {\n  SuiteHeaderApplicationPropTypes,\n  SuiteHeaderWorkspacePropTypes,\n} from '../SuiteHeaderPropTypes';",
          "computed": true
        }
      },
      "required": false
    },
    "globalApplications": {
      "defaultValue": {
        "value": "[]",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "shape",
          "value": "import {\n  SuiteHeaderApplicationPropTypes,\n  SuiteHeaderWorkspacePropTypes,\n} from '../SuiteHeaderPropTypes';",
          "computed": true
        }
      },
      "required": false
    },
    "onRouteChange": {
      "defaultValue": {
        "value": "async () => true",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "func"
      },
      "required": false
    },
    "i18n": {
      "defaultValue": {
        "value": "{\n  workspace: 'Workspace',\n  workspaces: 'Workspaces',\n  workspaceAdmin: 'Workspace administration',\n  backToAppSwitcher: 'Back to applications',\n  selectWorkspace: 'Select a workspace',\n  availableWorkspaces: 'Available workspaces',\n  suiteAdmin: 'Suite administration',\n  global: 'Global / other',\n  allApplicationsLink: 'All applications',\n  requestAccess: 'Contact your administrator to request application access.',\n  learnMoreLink: 'Learn more',\n}",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "shape",
        "value": {
          "workspace": {
            "name": "string",
            "required": false
          },
          "workspaces": {
            "name": "string",
            "required": false
          },
          "workspaceAdmin": {
            "name": "string",
            "required": false
          },
          "backToAppSwitcher": {
            "name": "string",
            "required": false
          },
          "selectWorkspace": {
            "name": "string",
            "required": false
          },
          "availableWorkspaces": {
            "name": "string",
            "required": false
          },
          "suiteAdmin": {
            "name": "string",
            "required": false
          },
          "allApplicationsLink": {
            "name": "string",
            "required": false
          },
          "requestAccess": {
            "name": "string",
            "required": false
          },
          "learnMoreLink": {
            "name": "string",
            "required": false
          }
        }
      },
      "required": false
    },
    "testId": {
      "defaultValue": {
        "value": "'multi-workspace-suite-header-app-switcher'",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "isExpanded": {
      "defaultValue": {
        "value": "false",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "bool"
      },
      "required": false
    },
    "workspaces": {
      "defaultValue": {
        "value": "null",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "shape",
          "value": "import {\n  SuiteHeaderApplicationPropTypes,\n  SuiteHeaderWorkspacePropTypes,\n} from '../SuiteHeaderPropTypes';",
          "computed": true
        }
      },
      "required": false
    },
    "noAccessLink": {
      "defaultValue": {
        "value": "null",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "adminLink": {
      "defaultValue": {
        "value": "null",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "isAdminView": {
      "defaultValue": {
        "value": "false",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "bool"
      },
      "required": false
    }
  }
};
var MultiWorkspaceSuiteHeaderAppSwitcher$1 = MultiWorkspaceSuiteHeaderAppSwitcher;

export { MultiWorkspaceSuiteHeaderAppSwitcher$1 as default };
