import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import _slicedToArray from '@babel/runtime/helpers/slicedToArray';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _pick from '../../../node_modules/lodash-es/pick.js';
import isNil from '../../../node_modules/lodash-es/isNil.js';
import 'core-js/modules/es.symbol.js';
import 'core-js/modules/es.array.concat.js';
import 'core-js/modules/es.array.filter.js';
import 'core-js/modules/es.array.map.js';
import 'core-js/modules/es.function.name.js';
import 'core-js/modules/es.object.get-own-property-descriptor.js';
import 'core-js/modules/es.object.get-own-property-descriptors.js';
import 'core-js/modules/es.object.keys.js';
import 'core-js/modules/es.object.to-string.js';
import 'core-js/modules/es.regexp.exec.js';
import 'core-js/modules/es.string.search.js';
import 'core-js/modules/web.dom-collections.for-each.js';
import React__default, { useMemo } from 'react';
import PropTypes from 'prop-types';
import { TableToolbar as TableToolbar$2, TableBatchActions, TableBatchAction, OverflowMenuItem, TableToolbarContent } from '@carbon/react';
import classnames from 'classnames';
import { useLangDirection } from 'use-lang-direction';
import { Tooltip } from '../../Tooltip/index.js';
import { OverflowMenu } from '../../OverflowMenu/index.js';
import Button from '../../Button/Button.js';
import deprecate from '../../../internal/deprecate.js';
import { ActiveTableToolbarPropType, TableFiltersPropType, TableColumnsPropTypes, TableOrderingPropType, TableSharedActionPropTypes, TableSharedOverflowMenuPropTypes, TableSearchPropTypes, TableToolbarActionsPropType, TableRowsPropTypes, defaultI18NPropTypes } from '../TablePropTypes.js';
import { tableTranslateWithId } from '../../../utils/componentUtilityFunctions.js';
import { settings } from '../../../constants/Settings.js';
import { RuleGroupPropType } from '../../RuleBuilder/RuleBuilderPropTypes.js';
import useDynamicOverflowMenuItems from '../../../hooks/useDynamicOverflowMenuItems.js';
import { renderTableOverflowItemText } from '../tableUtilities.js';
import TableToolbarAdvancedFilterFlyout from './TableToolbarAdvancedFilterFlyout.js';
import TableToolbarSVGButton from './TableToolbarSVGButton.js';
import TableToolbarSearch from './TableToolbarSearch.js';
import { OverflowMenuVertical, Download, Column, Filter, Edit } from '@carbon/icons-react';

var _excluded = ["id", "labelText", "disabled"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var iotPrefix = settings.iotPrefix;
var propTypes = {
  /** id of table */
  tableId: PropTypes.string.isRequired,
  secondaryTitle: PropTypes.string,
  tooltip: PropTypes.node,
  /** global table options */
  options: PropTypes.shape({
    hasAdvancedFilter: PropTypes.bool,
    hasAggregations: PropTypes.bool,
    /* option to hide batch action toolbar */
    hasBatchActionToolbar: PropTypes.bool,
    /** If true, search is applied as typed. If false, only after 'Enter' is pressed */
    hasFastSearch: PropTypes.bool,
    hasFilter: PropTypes.bool,
    hasSearch: PropTypes.bool,
    hasColumnSelection: PropTypes.bool,
    hasRowEdit: PropTypes.bool,
    hasRowSelection: PropTypes.oneOf(['multi', 'single', false]),
    onApplySearch: PropTypes.func,
    onDownloadCSV: PropTypes.func,
    onApplyAdvancedFilter: PropTypes.func,
    /** Optional boolean to render rowCount in header
     *  NOTE: Deprecated in favor of secondaryTitle for custom use
     */
    hasRowCountInHeader: deprecate(PropTypes.bool, '\n The prop `hasRowCountInHeader` has been deprecated in favor `secondaryTitle`'),
    // True if use can save/load views
    hasUserViewManagement: PropTypes.bool
  }).isRequired,
  /** internationalized labels */
  i18n: PropTypes.shape({
    clearAllFilters: PropTypes.string,
    columnSelectionButtonAria: PropTypes.string,
    filterButtonAria: PropTypes.string,
    editButtonAria: PropTypes.string,
    searchLabel: PropTypes.string,
    searchPlaceholder: PropTypes.string,
    batchCancel: PropTypes.string,
    itemsSelected: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
    itemSelected: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
    filterNone: PropTypes.string,
    filterAscending: PropTypes.string,
    filterDescending: PropTypes.string,
    toggleAggregations: PropTypes.string,
    toolbarLabelAria: PropTypes.string,
    rowCountInHeader: PropTypes.func,
    downloadIconDescription: PropTypes.string,
    /** aria-label applied to the tooltip in the toolbar (if given) */
    toolbarTooltipLabel: PropTypes.string,
    /** button label for batch action overflow menu */
    batchActionsOverflowMenuText: PropTypes.string,
    /** I18N label for search icon in toolbar */
    toolbarSearchIconDescription: PropTypes.string
  }),
  /**
   * Action callbacks to update tableState
   */
  actions: PropTypes.shape({
    onCancelBatchAction: PropTypes.func,
    onApplyBatchAction: PropTypes.func,
    onClearAllFilters: PropTypes.func,
    onToggleAggregations: PropTypes.func,
    onToggleColumnSelection: PropTypes.func,
    onToggleFilter: PropTypes.func,
    onToggleAdvancedFilter: PropTypes.func,
    onCreateAdvancedFilter: PropTypes.func,
    onChangeAdvancedFilter: PropTypes.func,
    onCancelAdvancedFilter: PropTypes.func,
    onApplyAdvancedFilter: PropTypes.func,
    onShowRowEdit: PropTypes.func,
    onApplySearch: PropTypes.func,
    onDownloadCSV: PropTypes.func,
    onApplyToolbarAction: PropTypes.func,
    onSearchExpand: PropTypes.func
  }).isRequired,
  /**
   * Inbound tableState
   */
  tableState: PropTypes.shape({
    /** is the toolbar currently disabled */
    isDisabled: PropTypes.bool,
    /** Which toolbar is currently active */
    activeBar: ActiveTableToolbarPropType,
    /** total number of selected rows */
    totalSelected: PropTypes.number,
    totalItemsCount: PropTypes.number,
    advancedFilterFlyoutOpen: PropTypes.bool,
    totalFilters: PropTypes.number,
    filters: TableFiltersPropType,
    columns: TableColumnsPropTypes,
    ordering: TableOrderingPropType,
    /** row selection option */
    hasRowSelection: PropTypes.oneOf(['multi', 'single', false]),
    /** optional content to render inside the toolbar  */
    customToolbarContent: PropTypes.node,
    /** available batch actions */
    batchActions: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.shape(_objectSpread(_objectSpread({}, TableSharedActionPropTypes), {}, {
      iconDescription: PropTypes.string
    })), PropTypes.shape(_objectSpread(_objectSpread({}, TableSharedOverflowMenuPropTypes), {}, {
      iconDescription: PropTypes.string
    }))])),
    search: TableSearchPropTypes,
    /** buttons to be shown with when activeBar is 'rowEdit' */
    rowEditBarButtons: PropTypes.node,
    /** a stripped down version of the RuleBuilderFilterPropType */
    advancedFilters: PropTypes.arrayOf(PropTypes.shape({
      /** Unique id for particular filter */
      filterId: PropTypes.string.isRequired,
      /** Text for main title of page */
      filterTitleText: PropTypes.string.isRequired,
      filterRules: RuleGroupPropType.isRequired
    })),
    /** currently selected advanced filters */
    selectedAdvancedFilterIds: PropTypes.arrayOf(PropTypes.string),
    /** toolbar actions that can appear in an overflow menu in the toolbar (same menu as toggle aggregations) */
    toolbarActions: TableToolbarActionsPropType,
    /** force hide Clear all filters button in toolbar */
    hideClearAllFiltersButton: PropTypes.bool
  }).isRequired,
  /** Row value data for the body of the table */
  data: TableRowsPropTypes.isRequired,
  // TODO: remove deprecated 'testID' in v3
  // eslint-disable-next-line react/require-default-props
  testID: deprecate(PropTypes.string, "The 'testID' prop has been deprecated. Please use 'testId' instead."),
  testId: PropTypes.string
};
var defaultProps = {
  i18n: _objectSpread({}, defaultI18NPropTypes),
  secondaryTitle: null,
  tooltip: null,
  testId: ''
};
var TableToolbar = function TableToolbar(_ref) {
  var tableId = _ref.tableId,
    className = _ref.className,
    i18n = _ref.i18n,
    secondaryTitle = _ref.secondaryTitle,
    tooltip = _ref.tooltip,
    _ref$options = _ref.options,
    hasAdvancedFilter = _ref$options.hasAdvancedFilter,
    hasAggregations = _ref$options.hasAggregations,
    hasColumnSelection = _ref$options.hasColumnSelection,
    hasFastSearch = _ref$options.hasFastSearch,
    hasFilter = _ref$options.hasFilter,
    hasSearch = _ref$options.hasSearch,
    hasRowSelection = _ref$options.hasRowSelection,
    hasRowCountInHeader = _ref$options.hasRowCountInHeader,
    hasRowEdit = _ref$options.hasRowEdit,
    hasUserViewManagement = _ref$options.hasUserViewManagement,
    hasBatchActionToolbar = _ref$options.hasBatchActionToolbar,
    _ref$actions = _ref.actions,
    onCancelBatchAction = _ref$actions.onCancelBatchAction,
    onApplyBatchAction = _ref$actions.onApplyBatchAction,
    onClearAllFilters = _ref$actions.onClearAllFilters,
    onToggleAggregations = _ref$actions.onToggleAggregations,
    onToggleColumnSelection = _ref$actions.onToggleColumnSelection,
    onToggleFilter = _ref$actions.onToggleFilter,
    onShowRowEdit = _ref$actions.onShowRowEdit,
    onApplySearch = _ref$actions.onApplySearch,
    onDownloadCSV = _ref$actions.onDownloadCSV,
    onApplyAdvancedFilter = _ref$actions.onApplyAdvancedFilter,
    onCancelAdvancedFilter = _ref$actions.onCancelAdvancedFilter,
    onCreateAdvancedFilter = _ref$actions.onCreateAdvancedFilter,
    onChangeAdvancedFilter = _ref$actions.onChangeAdvancedFilter,
    onToggleAdvancedFilter = _ref$actions.onToggleAdvancedFilter,
    onApplyToolbarAction = _ref$actions.onApplyToolbarAction,
    onSearchExpand = _ref$actions.onSearchExpand,
    _ref$tableState = _ref.tableState,
    advancedFilterFlyoutOpen = _ref$tableState.advancedFilterFlyoutOpen,
    advancedFilters = _ref$tableState.advancedFilters,
    totalSelected = _ref$tableState.totalSelected,
    totalFilters = _ref$tableState.totalFilters,
    batchActions = _ref$tableState.batchActions,
    searchProp = _ref$tableState.search,
    activeBar = _ref$tableState.activeBar,
    customToolbarContent = _ref$tableState.customToolbarContent,
    isDisabled = _ref$tableState.isDisabled,
    totalItemsCount = _ref$tableState.totalItemsCount,
    rowEditBarButtons = _ref$tableState.rowEditBarButtons,
    filters = _ref$tableState.filters,
    selectedAdvancedFilterIds = _ref$tableState.selectedAdvancedFilterIds,
    columns = _ref$tableState.columns,
    ordering = _ref$tableState.ordering,
    toolbarActions = _ref$tableState.toolbarActions,
    hideClearAllFiltersButton = _ref$tableState.hideClearAllFiltersButton,
    data = _ref.data,
    testID = _ref.testID,
    testId = _ref.testId;
  var shouldShowBatchActions = hasRowSelection === 'multi' && totalSelected > 0;
  var langDir = useLangDirection();
  var _useDynamicOverflowMe = useDynamicOverflowMenuItems({
      actions: toolbarActions,
      className: "".concat(iotPrefix, "--table-toolbar-aggregations__overflow-menu-content"),
      isDisabled: isDisabled,
      onClick: onApplyToolbarAction,
      testId: testID || testId
    }),
    _useDynamicOverflowMe2 = _slicedToArray(_useDynamicOverflowMe, 3),
    isOpen = _useDynamicOverflowMe2[0],
    setIsOpen = _useDynamicOverflowMe2[1],
    renderToolbarOverflowActions = _useDynamicOverflowMe2[2];
  var actions = useMemo(function () {
    var renderedActions = typeof toolbarActions === 'function' ? toolbarActions() : toolbarActions;
    return renderedActions !== null && renderedActions !== void 0 && renderedActions.length ? renderedActions : [];
  }, [toolbarActions]);
  var hasToolbarOverflowActions = actions.filter(function (action) {
    return action.isOverflow && action.hidden !== true;
  }).length > 0;
  var visibleToolbarActions = actions.filter(function (action) {
    return !action.isOverflow && action.hidden !== true;
  });
  var visibleBatchActions = batchActions.filter(function (action) {
    return !action.isOverflow && action.hidden !== true;
  });
  var visibleOverflowBatchActions = batchActions.filter(function (action) {
    return action.isOverflow && action.hidden !== true;
  });
  var hasVisibleBatchActions = visibleBatchActions.length > 0;
  var hasVisibleOverflowBatchActions = visibleOverflowBatchActions.length > 0;
  var totalSelectedText = useMemo(function () {
    if (totalSelected > 1) {
      if (typeof i18n.itemsSelected === 'function') {
        return i18n.itemsSelected(totalSelected);
      }
      return "".concat(totalSelected, " ").concat(i18n.itemsSelected);
    }
    if (typeof i18n.itemSelected === 'function') {
      return i18n.itemSelected(totalSelected);
    }
    return "".concat(totalSelected, " ").concat(i18n.itemSelected);
    /* eslint-disable-next-line react-hooks/exhaustive-deps */
  }, [i18n.itemSelected, i18n.itemsSelected, totalSelected]);
  return /*#__PURE__*/React__default.createElement(TableToolbar$2
  // TODO: remove deprecated 'testID' in v3
  , {
    "data-testid": testID || testId,
    className: classnames("".concat(iotPrefix, "--table-toolbar"), className),
    "aria-label": i18n.toolbarLabelAria
  }, hasBatchActionToolbar ? /*#__PURE__*/React__default.createElement(TableBatchActions
  // TODO: remove deprecated 'testID' in v3
  , {
    "data-testid": "".concat(testID || testId, "-batch-actions"),
    className: "".concat(iotPrefix, "--table-batch-actions"),
    onCancel: onCancelBatchAction,
    shouldShowBatchActions: shouldShowBatchActions,
    totalSelected: totalSelected,
    translateWithId: function translateWithId() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }
      return tableTranslateWithId.apply(void 0, [i18n].concat(args));
    }
  }, hasVisibleBatchActions && visibleBatchActions.map(function (_ref2) {
    var id = _ref2.id,
      labelText = _ref2.labelText,
      disabled = _ref2.disabled,
      others = _objectWithoutProperties(_ref2, _excluded);
    return /*#__PURE__*/React__default.createElement(TableBatchAction, _extends({
      key: id,
      onClick: function onClick() {
        return onApplyBatchAction(id);
      },
      tabIndex: shouldShowBatchActions ? 0 : -1,
      disabled: !shouldShowBatchActions || disabled
    }, others), labelText);
  }), hasVisibleOverflowBatchActions ? /*#__PURE__*/React__default.createElement(OverflowMenu, {
    "data-testid": "".concat(testID || testId, "-batch-actions-overflow-menu"),
    className: "".concat(iotPrefix, "--table-overflow-batch-actions"),
    flipped: langDir === 'ltr',
    direction: "bottom",
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    renderIcon: function renderIcon(props) {
      return /*#__PURE__*/React__default.createElement(OverflowMenuVertical, _extends({
        size: 16
      }, props));
    },
    tabIndex: shouldShowBatchActions ? 0 : -1,
    size: "md",
    menuOptionsClass: "".concat(iotPrefix, "--table-overflow-batch-actions__menu"),
    withCarbonTooltip: true,
    tooltipPosition: "bottom",
    buttonLabel: i18n.batchActionsOverflowMenuText
  }, visibleOverflowBatchActions.map(function (_ref3) {
    var id = _ref3.id,
      labelText = _ref3.labelText,
      disabled = _ref3.disabled,
      hasDivider = _ref3.hasDivider,
      isDelete = _ref3.isDelete,
      renderIcon = _ref3.renderIcon,
      iconDescription = _ref3.iconDescription;
    return /*#__PURE__*/React__default.createElement(OverflowMenuItem, {
      "data-testid": "".concat(testID || testId, "-batch-actions-overflow-menu-item-").concat(id),
      itemText: renderTableOverflowItemText({
        action: {
          renderIcon: renderIcon,
          labelText: labelText || iconDescription
        },
        className: "".concat(iotPrefix, "--table-toolbar-aggregations__overflow-menu-content")
      }),
      disabled: !shouldShowBatchActions || disabled,
      onClick: function onClick() {
        return onApplyBatchAction(id);
      },
      key: "table-batch-actions-overflow-menu-".concat(id),
      requireTitle: !renderIcon,
      hasDivider: hasDivider,
      isDelete: isDelete,
      "aria-label": labelText
    });
  })) : null) : null, secondaryTitle ?
  /*#__PURE__*/
  // eslint-disable-next-line jsx-a11y/label-has-associated-control, jsx-a11y/label-has-for
  React__default.createElement("label", {
    className: "".concat(iotPrefix, "--table-toolbar-secondary-title")
  }, secondaryTitle) : !hasBatchActionToolbar && shouldShowBatchActions ?
  /*#__PURE__*/
  // eslint-disable-next-line jsx-a11y/label-has-associated-control, jsx-a11y/label-has-for
  React__default.createElement("label", {
    className: "".concat(iotPrefix, "--table-toolbar-secondary-title")
  }, totalSelectedText) : null,
  // Deprecated in favor of secondaryTitle for a more general use-case
  hasRowCountInHeader ?
  /*#__PURE__*/
  // eslint-disable-next-line jsx-a11y/label-has-associated-control, jsx-a11y/label-has-for
  React__default.createElement("label", {
    className: "".concat(iotPrefix, "--table-toolbar-secondary-title")
  }, i18n.rowCountInHeader(totalItemsCount)) : null, tooltip && /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(iotPrefix, "--table-tooltip-container")
  }, /*#__PURE__*/React__default.createElement(Tooltip, {
    triggerId: "card-tooltip-trigger-".concat(tableId),
    tooltipId: "card-tooltip-".concat(tableId),
    triggerText: "",
    iconDescription: i18n.toolbarTooltipLabel
  }, tooltip)), activeBar === 'rowEdit' ? /*#__PURE__*/React__default.createElement("div", {
    className: "".concat(iotPrefix, "--table-row-edit-actions")
  }, rowEditBarButtons) : /*#__PURE__*/React__default.createElement(TableToolbarContent
  // TODO: remove deprecated 'testID' in v3
  , {
    "data-testid": "".concat(testID || testId, "-content"),
    className: "".concat(iotPrefix, "--table-toolbar-content")
  }, hasSearch ? /*#__PURE__*/React__default.createElement(TableToolbarSearch, {
    tableId: tableId,
    i18n: i18n,
    options: {
      hasFastSearch: hasFastSearch,
      hasUserViewManagement: hasUserViewManagement
    },
    actions: {
      onApplySearch: onApplySearch,
      onSearchExpand: onSearchExpand
    },
    tableState: {
      search: searchProp,
      isDisabled: isDisabled
    },
    testId: testID || testId,
    langDir: langDir
  }) : null, totalFilters > 0 && !hideClearAllFiltersButton ? /*#__PURE__*/React__default.createElement(Button, {
    kind: "secondary",
    onClick: onClearAllFilters,
    disabled: isDisabled,
    testId: "".concat(testId, "-clear-filters-button")
  }, i18n.clearAllFilters) : null, onDownloadCSV ? /*#__PURE__*/React__default.createElement(TableToolbarSVGButton, {
    onClick: function onClick() {
      // hand back the filtered data
      onDownloadCSV(data);
    },
    description: i18n.downloadIconDescription,
    testId: "download-button",
    renderIcon: Download,
    disabled: isDisabled,
    langDir: langDir
  }) : null, hasColumnSelection ? /*#__PURE__*/React__default.createElement(TableToolbarSVGButton, {
    isActive: activeBar === 'column',
    onClick: onToggleColumnSelection,
    description: i18n.columnSelectionButtonAria,
    testId: "column-selection-button",
    renderIcon: Column,
    disabled: isDisabled,
    langDir: langDir
  }) : null, hasFilter ? /*#__PURE__*/React__default.createElement(TableToolbarSVGButton, {
    isActive: activeBar === 'filter',
    onClick: onToggleFilter,
    description: i18n.filterButtonAria,
    testId: "filter-button",
    renderIcon: Filter,
    disabled: isDisabled,
    langDir: langDir
  }) : null, hasAdvancedFilter ? /*#__PURE__*/React__default.createElement(TableToolbarAdvancedFilterFlyout, {
    actions: {
      onApplyAdvancedFilter: onApplyAdvancedFilter,
      onCancelAdvancedFilter: onCancelAdvancedFilter,
      onCreateAdvancedFilter: onCreateAdvancedFilter,
      onChangeAdvancedFilter: onChangeAdvancedFilter,
      onToggleAdvancedFilter: onToggleAdvancedFilter
    },
    columns: columns.map(function (column) {
      var _column$filter, _column$filter2;
      return _objectSpread(_objectSpread({}, column.filter), {}, {
        id: column.id,
        name: column.name,
        isDate: (_column$filter = column.filter) === null || _column$filter === void 0 ? void 0 : _column$filter.isDate,
        isFilterable: !isNil(column.filter),
        isMultiselect: (_column$filter2 = column.filter) === null || _column$filter2 === void 0 ? void 0 : _column$filter2.isMultiselect
      });
    }),
    tableState: {
      filters: filters,
      advancedFilters: advancedFilters,
      selectedAdvancedFilterIds: selectedAdvancedFilterIds,
      advancedFilterFlyoutOpen: advancedFilterFlyoutOpen,
      ordering: ordering,
      hasFastFilter: hasAdvancedFilter === 'onKeyPress',
      isDisabled: isDisabled
    },
    i18n: _objectSpread({}, _pick(i18n, 'filterText', 'clearFilterText', 'clearSelectionText', 'openMenuText', 'closeMenuText', 'applyButtonText', 'cancelButtonText', 'advancedFilterLabelText', 'createNewAdvancedFilterText', 'advancedFilterPlaceholderText', 'simpleFiltersTabLabel', 'advancedFiltersTabLabel'))
  }) : null, hasRowEdit ? /*#__PURE__*/React__default.createElement(TableToolbarSVGButton, {
    isActive: activeBar === 'rowEdit',
    description: i18n.editButtonAria,
    onClick: onShowRowEdit,
    testId: "row-edit-button",
    renderIcon: function renderIcon(props) {
      return /*#__PURE__*/React__default.createElement(Edit, _extends({
        size: 16
      }, props));
    },
    disabled: isDisabled,
    langDir: langDir
  }) : null, visibleToolbarActions.map(function (action) {
    return /*#__PURE__*/React__default.createElement(TableToolbarSVGButton, {
      isActive: action.isActive,
      description: action.labelText || action.iconDescription,
      onClick: function onClick(e) {
        e.stopPropagation();
        onApplyToolbarAction(action);
      },
      testId: "".concat(tableId, "-toolbar-actions-button-").concat(action.id),
      key: "".concat(tableId, "-toolbar-actions-button-").concat(action.id),
      renderIcon: action.renderIcon,
      disabled: isDisabled || action.disabled,
      langDir: langDir
    });
  }), hasAggregations || hasToolbarOverflowActions ? /*#__PURE__*/React__default.createElement(OverflowMenu, {
    className: "".concat(iotPrefix, "--table-toolbar-aggregations__overflow-menu"),
    direction: "bottom",
    flipped: langDir === 'ltr',
    "data-testid": "table-head--overflow",
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    renderIcon: function renderIcon(props) {
      return /*#__PURE__*/React__default.createElement(OverflowMenuVertical, _extends({
        size: 16
      }, props));
    },
    iconClass: "".concat(iotPrefix, "--table-toolbar-aggregations__overflow-icon"),
    onOpen: function onOpen() {
      return setIsOpen(true);
    },
    onClose: function onClose() {
      return setIsOpen(false);
    },
    withCarbonTooltip: true,
    tooltipPosition: "bottom"
  }, hasAggregations && /*#__PURE__*/React__default.createElement(OverflowMenuItem, {
    "data-testid": "".concat(testID || testId, "-toolbar-overflow-menu-item-aggregations"),
    itemText: i18n.toggleAggregations,
    key: "table-aggregations-overflow-item",
    onClick: function onClick() {
      setIsOpen(false);
      onToggleAggregations();
    },
    disabled: isDisabled
  }), isOpen && renderToolbarOverflowActions(),
  /**
   * a placeholder node to ensure the menu will always open. If there are no children,
   * the renderToolbarOverflowAction method above will never fire, because the
   * OverflowMenu doesn't open properly if no children are provided.
   */
  !isOpen && /*#__PURE__*/React__default.createElement(OverflowMenuItem, {
    itemText: "",
    disabled: true
  })) : null,
  // Default card header actions should be to the right of the table-specific actions
  customToolbarContent || null));
};
TableToolbar.propTypes = propTypes;
TableToolbar.defaultProps = defaultProps;
TableToolbar.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "TableToolbar",
  "props": {
    "i18n": {
      "defaultValue": {
        "value": "{\n  ...defaultI18NPropTypes,\n}",
        "computed": false
      },
      "description": "internationalized labels",
      "type": {
        "name": "shape",
        "value": {
          "clearAllFilters": {
            "name": "string",
            "required": false
          },
          "columnSelectionButtonAria": {
            "name": "string",
            "required": false
          },
          "filterButtonAria": {
            "name": "string",
            "required": false
          },
          "editButtonAria": {
            "name": "string",
            "required": false
          },
          "searchLabel": {
            "name": "string",
            "required": false
          },
          "searchPlaceholder": {
            "name": "string",
            "required": false
          },
          "batchCancel": {
            "name": "string",
            "required": false
          },
          "itemsSelected": {
            "name": "union",
            "value": [{
              "name": "string"
            }, {
              "name": "func"
            }],
            "required": false
          },
          "itemSelected": {
            "name": "union",
            "value": [{
              "name": "string"
            }, {
              "name": "func"
            }],
            "required": false
          },
          "filterNone": {
            "name": "string",
            "required": false
          },
          "filterAscending": {
            "name": "string",
            "required": false
          },
          "filterDescending": {
            "name": "string",
            "required": false
          },
          "toggleAggregations": {
            "name": "string",
            "required": false
          },
          "toolbarLabelAria": {
            "name": "string",
            "required": false
          },
          "rowCountInHeader": {
            "name": "func",
            "required": false
          },
          "downloadIconDescription": {
            "name": "string",
            "required": false
          },
          "toolbarTooltipLabel": {
            "name": "string",
            "description": "aria-label applied to the tooltip in the toolbar (if given)",
            "required": false
          },
          "batchActionsOverflowMenuText": {
            "name": "string",
            "description": "button label for batch action overflow menu",
            "required": false
          },
          "toolbarSearchIconDescription": {
            "name": "string",
            "description": "I18N label for search icon in toolbar",
            "required": false
          }
        }
      },
      "required": false
    },
    "secondaryTitle": {
      "defaultValue": {
        "value": "null",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "tooltip": {
      "defaultValue": {
        "value": "null",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "node"
      },
      "required": false
    },
    "testId": {
      "defaultValue": {
        "value": "''",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "tableId": {
      "description": "id of table",
      "type": {
        "name": "string"
      },
      "required": true
    },
    "options": {
      "description": "global table options",
      "type": {
        "name": "shape",
        "value": {
          "hasAdvancedFilter": {
            "name": "bool",
            "required": false
          },
          "hasAggregations": {
            "name": "bool",
            "required": false
          },
          "hasBatchActionToolbar": {
            "name": "bool",
            "required": false
          },
          "hasFastSearch": {
            "name": "bool",
            "description": "If true, search is applied as typed. If false, only after 'Enter' is pressed",
            "required": false
          },
          "hasFilter": {
            "name": "bool",
            "required": false
          },
          "hasSearch": {
            "name": "bool",
            "required": false
          },
          "hasColumnSelection": {
            "name": "bool",
            "required": false
          },
          "hasRowEdit": {
            "name": "bool",
            "required": false
          },
          "hasRowSelection": {
            "name": "enum",
            "value": [{
              "value": "'multi'",
              "computed": false
            }, {
              "value": "'single'",
              "computed": false
            }, {
              "value": "false",
              "computed": false
            }],
            "required": false
          },
          "onApplySearch": {
            "name": "func",
            "required": false
          },
          "onDownloadCSV": {
            "name": "func",
            "required": false
          },
          "onApplyAdvancedFilter": {
            "name": "func",
            "required": false
          },
          "hasRowCountInHeader": {
            "name": "custom",
            "raw": "deprecate(\n  PropTypes.bool,\n  '\\n The prop `hasRowCountInHeader` has been deprecated in favor `secondaryTitle`'\n)",
            "description": "Optional boolean to render rowCount in header\n NOTE: Deprecated in favor of secondaryTitle for custom use",
            "required": false
          },
          "hasUserViewManagement": {
            "name": "bool",
            "required": false
          }
        }
      },
      "required": true
    },
    "actions": {
      "description": "Action callbacks to update tableState",
      "type": {
        "name": "shape",
        "value": {
          "onCancelBatchAction": {
            "name": "func",
            "required": false
          },
          "onApplyBatchAction": {
            "name": "func",
            "required": false
          },
          "onClearAllFilters": {
            "name": "func",
            "required": false
          },
          "onToggleAggregations": {
            "name": "func",
            "required": false
          },
          "onToggleColumnSelection": {
            "name": "func",
            "required": false
          },
          "onToggleFilter": {
            "name": "func",
            "required": false
          },
          "onToggleAdvancedFilter": {
            "name": "func",
            "required": false
          },
          "onCreateAdvancedFilter": {
            "name": "func",
            "required": false
          },
          "onChangeAdvancedFilter": {
            "name": "func",
            "required": false
          },
          "onCancelAdvancedFilter": {
            "name": "func",
            "required": false
          },
          "onApplyAdvancedFilter": {
            "name": "func",
            "required": false
          },
          "onShowRowEdit": {
            "name": "func",
            "required": false
          },
          "onApplySearch": {
            "name": "func",
            "required": false
          },
          "onDownloadCSV": {
            "name": "func",
            "required": false
          },
          "onApplyToolbarAction": {
            "name": "func",
            "required": false
          },
          "onSearchExpand": {
            "name": "func",
            "required": false
          }
        }
      },
      "required": true
    },
    "tableState": {
      "description": "Inbound tableState",
      "type": {
        "name": "shape",
        "value": {
          "isDisabled": {
            "name": "bool",
            "description": "is the toolbar currently disabled",
            "required": false
          },
          "activeBar": {
            "name": "custom",
            "raw": "ActiveTableToolbarPropType",
            "description": "Which toolbar is currently active",
            "required": false
          },
          "totalSelected": {
            "name": "number",
            "description": "total number of selected rows",
            "required": false
          },
          "totalItemsCount": {
            "name": "number",
            "required": false
          },
          "advancedFilterFlyoutOpen": {
            "name": "bool",
            "required": false
          },
          "totalFilters": {
            "name": "number",
            "required": false
          },
          "filters": {
            "name": "custom",
            "raw": "TableFiltersPropType",
            "required": false
          },
          "columns": {
            "name": "custom",
            "raw": "TableColumnsPropTypes",
            "required": false
          },
          "ordering": {
            "name": "custom",
            "raw": "TableOrderingPropType",
            "required": false
          },
          "hasRowSelection": {
            "name": "enum",
            "value": [{
              "value": "'multi'",
              "computed": false
            }, {
              "value": "'single'",
              "computed": false
            }, {
              "value": "false",
              "computed": false
            }],
            "description": "row selection option",
            "required": false
          },
          "customToolbarContent": {
            "name": "node",
            "description": "optional content to render inside the toolbar",
            "required": false
          },
          "batchActions": {
            "name": "arrayOf",
            "value": {
              "name": "union",
              "value": [{
                "name": "shape",
                "value": {
                  "iconDescription": {
                    "name": "string",
                    "required": false
                  }
                }
              }, {
                "name": "shape",
                "value": {
                  "iconDescription": {
                    "name": "string",
                    "required": false
                  }
                }
              }]
            },
            "description": "available batch actions",
            "required": false
          },
          "search": {
            "name": "custom",
            "raw": "TableSearchPropTypes",
            "required": false
          },
          "rowEditBarButtons": {
            "name": "node",
            "description": "buttons to be shown with when activeBar is 'rowEdit'",
            "required": false
          },
          "advancedFilters": {
            "name": "arrayOf",
            "value": {
              "name": "shape",
              "value": {
                "filterId": {
                  "name": "string",
                  "description": "Unique id for particular filter",
                  "required": true
                },
                "filterTitleText": {
                  "name": "string",
                  "description": "Text for main title of page",
                  "required": true
                },
                "filterRules": {
                  "name": "custom",
                  "raw": "RuleGroupPropType.isRequired",
                  "required": true
                }
              }
            },
            "description": "a stripped down version of the RuleBuilderFilterPropType",
            "required": false
          },
          "selectedAdvancedFilterIds": {
            "name": "arrayOf",
            "value": {
              "name": "string"
            },
            "description": "currently selected advanced filters",
            "required": false
          },
          "toolbarActions": {
            "name": "custom",
            "raw": "TableToolbarActionsPropType",
            "description": "toolbar actions that can appear in an overflow menu in the toolbar (same menu as toggle aggregations)",
            "required": false
          },
          "hideClearAllFiltersButton": {
            "name": "bool",
            "description": "force hide Clear all filters button in toolbar",
            "required": false
          }
        }
      },
      "required": true
    },
    "data": {
      "description": "Row value data for the body of the table",
      "type": {
        "name": "custom",
        "raw": "TableRowsPropTypes.isRequired"
      },
      "required": false
    },
    "testID": {
      "description": "",
      "type": {
        "name": "custom",
        "raw": "deprecate(\n  PropTypes.string,\n  `The 'testID' prop has been deprecated. Please use 'testId' instead.`\n)"
      },
      "required": false
    }
  }
};
var TableToolbar$1 = TableToolbar;

export { TableToolbar$1 as default };
