import { useRef, useEffect } from 'react';

/**
 * Copyright IBM Corp. 2016, 2023
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */


/**
 * @template {keyof WindowEventMap} E
 * @typedef {(event: WindowEventMap[E]) => void} WindowEventCallback
 */

/**
 * @template {keyof WindowEventMap} E
 * @param {E} eventName
 * @param {WindowEventCallback<E>} callback
 */
function useWindowEvent(eventName, callback) {
  /**
   * @type {MutableRefObject<WindowEventCallback<E> | null>}
   */
  const savedCallback = useRef(null);
  useEffect(() => {
    savedCallback.current = callback;
  }, [callback]);
  useEffect(() => {
    /**
     * @type {WindowEventCallback<E>}
     */
    function handler(event) {
      if (savedCallback.current) {
        savedCallback.current(event);
      }
    }
    window.addEventListener(eventName, handler);
    return () => {
      window.removeEventListener(eventName, handler);
    };
  }, [eventName]);
}

export { useWindowEvent };
