'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _toConsumableArray = require('@babel/runtime/helpers/toConsumableArray');
var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var _typeof = require('@babel/runtime/helpers/typeof');
var _slicedToArray = require('@babel/runtime/helpers/slicedToArray');
require('core-js/modules/es.symbol.js');
require('core-js/modules/es.array.concat.js');
require('core-js/modules/es.array.filter.js');
require('core-js/modules/es.array.from.js');
require('core-js/modules/es.array.includes.js');
require('core-js/modules/es.array.map.js');
require('core-js/modules/es.array.slice.js');
require('core-js/modules/es.object.get-own-property-descriptor.js');
require('core-js/modules/es.object.get-own-property-descriptors.js');
require('core-js/modules/es.object.keys.js');
require('core-js/modules/es.object.to-string.js');
require('core-js/modules/es.regexp.constructor.js');
require('core-js/modules/es.regexp.exec.js');
require('core-js/modules/es.regexp.to-string.js');
require('core-js/modules/es.string.includes.js');
require('core-js/modules/es.string.iterator.js');
require('core-js/modules/web.dom-collections.for-each.js');
var React = require('react');
var ReactDOM = require('react-dom');
var PropTypes = require('prop-types');
var dayjs = require('dayjs');
var react = require('@carbon/react');
var classnames = require('classnames');
var Settings = require('../../constants/Settings.js');
var KeyCodeConstants = require('../../constants/KeyCodeConstants.js');
var useMerged = require('../../hooks/useMerged.js');
var ListSpinner = require('./ListSpinner.js');
var iconsReact = require('@carbon/icons-react');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var _toConsumableArray__default = /*#__PURE__*/_interopDefault(_toConsumableArray);
var _defineProperty__default = /*#__PURE__*/_interopDefault(_defineProperty);
var _typeof__default = /*#__PURE__*/_interopDefault(_typeof);
var _slicedToArray__default = /*#__PURE__*/_interopDefault(_slicedToArray);
var React__default = /*#__PURE__*/_interopDefault(React);
var ReactDOM__default = /*#__PURE__*/_interopDefault(ReactDOM);
var PropTypes__default = /*#__PURE__*/_interopDefault(PropTypes);
var dayjs__default = /*#__PURE__*/_interopDefault(dayjs);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty__default.default(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var iotPrefix = Settings.settings.iotPrefix,
  prefix = Settings.settings.prefix;
var TIME_FORMAT = {
  12: 'hh:mm A',
  24: 'HH:mm'
};
var AVAILABLE_FORMATS = 'hhHHmmA';
var timeUtils = {
  get12Hours: function get12Hours(selectedTime, currentTime) {
    return /(0[1-9])|(1[0-2])/.test(selectedTime.substring(0, 2)) ? selectedTime.substring(0, 2) : currentTime.substring(0, 2);
  },
  get24Hours: function get24Hours(selectedTime, currentTime) {
    return /^(2[0-3]|[01]?[0-9])$/.test(selectedTime.substring(0, 2)) ? selectedTime.substring(0, 2) : currentTime.substring(2, 4);
  },
  getMinutes: function getMinutes(selectedTime, currentTime) {
    return /[0-5][0-9]/.test(selectedTime.substring(3, 5)) ? selectedTime.substring(3, 5) : currentTime.substring(4, 6);
  },
  getMeridiem: function getMeridiem(selectedTime, currentTime, amString, pmString) {
    return new RegExp("[".concat(amString, "|").concat(pmString, "]")).test(selectedTime.substring(selectedTime.length - 2)) ? selectedTime.substring(selectedTime.length - 2) : currentTime.substring(6);
  }
};
var propTypes = {
  className: PropTypes__default.default.string,
  id: PropTypes__default.default.string.isRequired,
  /** Specify the value for input */
  value: PropTypes__default.default.string,
  /** Specify the value for secondary input (range) */
  secondaryValue: PropTypes__default.default.string,
  /** Specify whether the input labels to be visually hidden */
  hideLabel: PropTypes__default.default.bool,
  /** Specify whether the secondary label to be visually hidden */
  hideSecondaryLabel: PropTypes__default.default.bool,
  /** Input can be for a single time or a range - defaults to single */
  type: PropTypes__default.default.oneOf(['single', 'range']),
  i18n: PropTypes__default.default.shape({
    /** Label for input (will be first, if range type) */
    labelText: PropTypes__default.default.string.isRequired,
    helperText: PropTypes__default.default.string,
    /** Label for second input in range */
    secondaryLabelText: PropTypes__default.default.string,
    secondaryHelperText: PropTypes__default.default.string,
    invalidText: PropTypes__default.default.string,
    warnText: PropTypes__default.default.string,
    timeIconText: PropTypes__default.default.string,
    placeholderText: PropTypes__default.default.string,
    placeholderText24h: PropTypes__default.default.string,
    amString: PropTypes__default.default.string,
    pmString: PropTypes__default.default.string
  }),
  /** Size of input */
  size: PropTypes__default.default.oneOf(['sm', 'md', 'lg']),
  /** Specify whether the control is currently disabled */
  disabled: PropTypes__default.default.bool,
  /** Specify whether the control is currently read only */
  readOnly: PropTypes__default.default.bool,
  /** Specify whether the control is currently in warning state */
  warn: PropTypes__default.default.arrayOf(PropTypes__default.default.bool),
  /** Specify whether the control is currently in invalid state */
  invalid: PropTypes__default.default.arrayOf(PropTypes__default.default.bool),
  /** Boolean to swap for light theme */
  light: PropTypes__default.default.bool,
  /** Optional handler that is called whenever <input> is updated - will be called with new value as an argument */
  onChange: PropTypes__default.default.func,
  testId: PropTypes__default.default.string,
  style: PropTypes__default.default.objectOf(PropTypes__default.default.oneOfType([PropTypes__default.default.string, PropTypes__default.default.number])),
  is24hours: PropTypes__default.default.bool
};

/* istanbul ignore next */
var defaultProps = {
  className: undefined,
  hideLabel: false,
  value: undefined,
  secondaryValue: undefined,
  hideSecondaryLabel: false,
  type: 'single',
  i18n: {
    invalidText: 'The time entered is invalid',
    warnText: undefined,
    timeIconText: 'Open time picker',
    placeholderText: 'hh:mm XM',
    placeholderText24h: 'HH:mm',
    readOnlyBtnText: 'Read only',
    amString: 'AM',
    pmString: 'PM'
  },
  size: 'md',
  disabled: false,
  readOnly: false,
  warn: [false, false],
  invalid: [false, false],
  light: false,
  onChange: function onChange() {},
  testId: 'time-picker',
  style: {},
  is24hours: false
};
var validate = function validate(newValue, is24hours, amString, pmString) {
  if (is24hours) {
    return /^(2[0-3]|[01]?[0-9]):([0-5]?[0-9])$/.test(newValue) || newValue === '';
  }
  var timeRegEx = /^((0[1-9])?|(1[0-2])?)*:[0-5][0-9]/;
  var meridianRegEx = new RegExp("".concat(amString, "|").concat(pmString));
  return timeRegEx.test(newValue.split(' ')[0]) && meridianRegEx.test(newValue.split(' ')[1]) || newValue === '';
};
var TimePickerDropdown = function TimePickerDropdown(_ref) {
  var id = _ref.id,
    className = _ref.className,
    type = _ref.type,
    i18n = _ref.i18n,
    size = _ref.size,
    disabled = _ref.disabled,
    testId = _ref.testId,
    warn = _ref.warn,
    invalid = _ref.invalid,
    light = _ref.light,
    readOnly = _ref.readOnly,
    hideLabel = _ref.hideLabel,
    hideSecondaryLabel = _ref.hideSecondaryLabel,
    value = _ref.value,
    secondaryValue = _ref.secondaryValue,
    onChange = _ref.onChange,
    style = _ref.style,
    is24hours = _ref.is24hours;
  var init = React.useRef(false);
  var inputRef = React.useRef();
  var secondaryInputRef = React.useRef();
  var dropDownRef = React.useRef();
  var container = inputRef.current;
  var invalidProp = invalid[0];
  var secondaryInvalidProp = invalid[1];
  var warnProp = warn[0];
  var secondaryWarnProp = warn[1];
  // Component state
  var _useState = React.useState(false),
    _useState2 = _slicedToArray__default.default(_useState, 2),
    openState = _useState2[0],
    setOpenState = _useState2[1];
  var _useState3 = React.useState([0, 0]),
    _useState4 = _slicedToArray__default.default(_useState3, 2),
    position = _useState4[0],
    setPosition = _useState4[1];
  var _useState5 = React.useState(0),
    _useState6 = _slicedToArray__default.default(_useState5, 2),
    focusedInput = _useState6[0],
    setFocusedInput = _useState6[1];
  var _useState7 = React.useState(value || ''),
    _useState8 = _slicedToArray__default.default(_useState7, 2),
    valueState = _useState8[0],
    setValueState = _useState8[1];
  var _useState9 = React.useState(secondaryValue || ''),
    _useState10 = _slicedToArray__default.default(_useState9, 2),
    secondaryValueState = _useState10[0],
    setSecondaryValueState = _useState10[1];
  var _useState11 = React.useState(invalidProp),
    _useState12 = _slicedToArray__default.default(_useState11, 2),
    invalidState = _useState12[0],
    setInvalidState = _useState12[1];
  var _useState13 = React.useState(secondaryInvalidProp),
    _useState14 = _slicedToArray__default.default(_useState13, 2),
    secondaryInvalidState = _useState14[0],
    setSecondaryInvalidState = _useState14[1];
  React.useEffect(function () {
    if (init.current) {
      onChange(valueState, secondaryValueState);
    } else {
      init.current = true;
    }
  }, [onChange, secondaryValueState, valueState, init]);
  React.useEffect(function () {
    setInvalidState(invalidProp);
    setSecondaryInvalidState(secondaryInvalidProp);
  }, [invalidProp, secondaryInvalidProp]);
  React.useEffect(function () {
    if (container) {
      var _container$getBoundin = container.getBoundingClientRect(),
        left = _container$getBoundin.left,
        bottom = _container$getBoundin.bottom;
      setPosition([left, bottom]);
    }
  }, [container, hideLabel]);
  var _useMerged = useMerged(defaultProps.i18n, i18n),
    labelText = _useMerged.labelText,
    secondaryLabelText = _useMerged.secondaryLabelText,
    helperText = _useMerged.helperText,
    invalidText = _useMerged.invalidText,
    warnText = _useMerged.warnText,
    timeIconText = _useMerged.timeIconText,
    placeholderText = _useMerged.placeholderText,
    placeholderText24h = _useMerged.placeholderText24h,
    readOnlyBtnText = _useMerged.readOnlyBtnText,
    amString = _useMerged.amString,
    pmString = _useMerged.pmString;
  React.useEffect(function () {
    if (openState) {
      var _container$getBoundin2 = container.getBoundingClientRect(),
        left = _container$getBoundin2.left,
        bottom = _container$getBoundin2.bottom,
        top = _container$getBoundin2.top;
      var dropdownHeight = 280;
      var scrollOffset = window.pageYOffset;
      var dropdownBottom = bottom + dropdownHeight;
      var dropdownPos = top - dropdownHeight + scrollOffset;
      if (dropdownBottom > window.innerHeight && dropdownPos > 0) {
        setPosition([left, dropdownPos]);
      } else {
        setPosition([left, bottom + scrollOffset]);
      }
    }
  }, [container, openState, focusedInput, is24hours, value, secondaryValue]);
  var handleOpenDropdown = function handleOpenDropdown(index) {
    if (focusedInput === index && openState === true) {
      setOpenState(false);
    } else {
      setOpenState(true);
    }
    setFocusedInput(index);
  };
  var handleOnFocus = function handleOnFocus(index) {
    setFocusedInput(index);
    if (!readOnly) {
      handleOpenDropdown(index);
      var current12HourTime = dayjs__default.default().format(TIME_FORMAT[12]).split(' ')[0];
      var current12HourMeridian = dayjs__default.default().format(TIME_FORMAT[12]).split(' ')[1] === 'AM' ? amString : pmString;
      var currentTime = is24hours ? dayjs__default.default().format(TIME_FORMAT[24]) : "".concat(current12HourTime, " ").concat(current12HourMeridian);
      if (index === 0 && !value) {
        setValueState(function (prevValue) {
          return prevValue || currentTime;
        });
      }
      if (index === 1 && !secondaryValue) {
        setSecondaryValueState(function (prevValue) {
          return prevValue || currentTime;
        });
      }
    }
  };
  var handleOnKeyDown = function handleOnKeyDown(e) {
    if (e.key === KeyCodeConstants.keyboardKeys.ESCAPE) {
      setOpenState(false);
    }
    if (e.key === KeyCodeConstants.keyboardKeys.DOWN && dropDownRef.current) {
      dropDownRef.current.focus();
    }
  };
  var handleOnKeyUp = function handleOnKeyUp(e) {
    if (e.key === KeyCodeConstants.keyboardKeys.ENTER && inputRef.current) {
      setOpenState(false);
      inputRef.current.focus();
    }
  };
  var handleOnChange = function handleOnChange(e) {
    var val = e;
    if (_typeof__default.default(e) === 'object') {
      val = e.target.value;
    }

    // match all the words combined provided by amString and pmString
    var isValidMeridian = new RegExp("[".concat(amString).concat(pmString, "]")).test(val.substring(val.length - 1));
    var isValidTime = /[0-9: ]/.test(val.substring(val.length - 1));
    // @TODO: detect the length and run validation for as many as we can
    // This value is pasted in or autocompleted
    // istanbul ignore else

    // match any of the full string of tranlated AM or PM
    var meridianRegEx = new RegExp("".concat(amString, "|").concat(pmString, "|").concat(defaultProps.i18n.amString, "|").concat(defaultProps.i18n.pmString), 'g');
    var newVal = val && meridianRegEx.test(val) && !is24hours ? val.split(' ')[1] === 'AM' || val.split(' ')[1] === amString ? "".concat(val.split(' ')[0], " ").concat(amString) : "".concat(val.split(' ')[0], " ").concat(pmString) : val;
    if (val.length > 1) {
      if (focusedInput === 0) {
        setValueState(newVal);
      } else {
        setSecondaryValueState(newVal);
      }
    } else if (isValidMeridian || isValidTime || val === '') {
      if (focusedInput === 0) {
        setValueState(newVal);
      } else {
        setSecondaryValueState(newVal);
      }
    }
  };
  var handleOnBlur = function handleOnBlur(e) {
    var _dropDownRef$current, _e$relatedTarget, _e$relatedTarget2;
    var contained = ((_dropDownRef$current = dropDownRef.current) === null || _dropDownRef$current === void 0 ? void 0 : _dropDownRef$current.contains(e.relatedTarget)) || e.currentTarget.contains(e.relatedTarget) || ((_e$relatedTarget = e.relatedTarget) === null || _e$relatedTarget === void 0 || (_e$relatedTarget = _e$relatedTarget.parentNode) === null || _e$relatedTarget === void 0 ? void 0 : _e$relatedTarget.classList[0].includes('iot--list-spinner')) || ((_e$relatedTarget2 = e.relatedTarget) === null || _e$relatedTarget2 === void 0 || (_e$relatedTarget2 = _e$relatedTarget2.parentNode) === null || _e$relatedTarget2 === void 0 ? void 0 : _e$relatedTarget2.classList[0].includes('iot--list-spinner'));
    if (!contained) {
      // close dropdown and validate
      setOpenState(false);
      setInvalidState(!validate(inputRef.current.value, is24hours, amString, pmString));
      /* istanbul ignore else */
      if (secondaryInputRef.current) {
        setSecondaryInvalidState(!validate(secondaryInputRef.current.value, is24hours, amString, pmString));
      }
    }
  };
  var inputState = React.useMemo(function () {
    return {
      state: invalidState && !readOnly ? 'invalid' : warnProp && !readOnly ? 'warn' : readOnly ? 'readOnly' : 'default',
      secondaryState: secondaryInvalidState && !readOnly ? 'invalid' : secondaryWarnProp && !readOnly ? 'warn' : readOnly ? 'readOnly' : 'default',
      firstIcon: invalidState && !readOnly ? iconsReact.WarningFilled : warnProp && !readOnly ? iconsReact.WarningAltFilled : readOnly ? iconsReact.EditOff : iconsReact.Time,
      secondIcon: secondaryInvalidState && !readOnly ? iconsReact.WarningFilled : secondaryWarnProp && !readOnly ? iconsReact.WarningAltFilled : readOnly ? iconsReact.EditOff : iconsReact.Time,
      text: !readOnly && invalidState ? invalidText : !readOnly && warnProp ? warnText : helperText,
      secondaryText: !readOnly && secondaryInvalidState ? invalidText : !readOnly && secondaryWarnProp ? warnText : helperText
    };
  }, [invalidState, secondaryInvalidState, warnProp, secondaryWarnProp, readOnly, invalidText, warnText, helperText]);
  return (
    /*#__PURE__*/
    // eslint-disable-next-line jsx-a11y/no-static-element-interactions
    React__default.default.createElement("div", {
      onBlur: handleOnBlur,
      onKeyDown: handleOnKeyDown,
      onKeyUp: handleOnKeyUp,
      "data-testid": testId,
      className: classnames__default.default("".concat(iotPrefix, "--time-picker"), _defineProperty__default.default(_defineProperty__default.default(_defineProperty__default.default(_defineProperty__default.default(_defineProperty__default.default(_defineProperty__default.default({}, className, className), "".concat(iotPrefix, "--time-picker--24h"), is24hours), "".concat(iotPrefix, "--time-picker--light"), light), "".concat(iotPrefix, "--time-picker--disabled"), disabled), "".concat(iotPrefix, "--time-picker-range"), type === 'range'), "".concat(iotPrefix, "--time-picker--warn"), inputState.state === 'warn' || inputState.secondaryState === 'warn' || warn[0] || warn[1]))
    }, type === 'single' ? /*#__PURE__*/React__default.default.createElement(React__default.default.Fragment, null, /*#__PURE__*/React__default.default.createElement("div", {
      className: classnames__default.default("".concat(iotPrefix, "--time-picker__wrapper ").concat(iotPrefix, "--time-picker__wrapper-").concat(size), _defineProperty__default.default(_defineProperty__default.default({}, "".concat(iotPrefix, "--time-picker__wrapper--selected"), focusedInput === 0 && openState), "".concat(iotPrefix, "--time-picker--invalid"), inputState.state === 'invalid'))
    }, /*#__PURE__*/React__default.default.createElement(react.TextInput, {
      onChange: handleOnChange,
      "data-testid": "".concat(testId, "-input"),
      id: id,
      value: valueState,
      onFocus: function onFocus() {
        return handleOnFocus(0);
      },
      readOnly: readOnly,
      hideLabel: hideLabel,
      labelText: labelText,
      placeholder: is24hours ? placeholderText24h : placeholderText,
      size: size,
      warn: warnProp,
      invalid: invalidState,
      light: light,
      disabled: disabled,
      ref: inputRef
    }), /*#__PURE__*/React__default.default.createElement("div", {
      "data-testid": "".concat(testId, "-time-btn"),
      title: readOnly ? readOnlyBtnText : timeIconText,
      className: classnames__default.default("".concat(iotPrefix, "--time-picker__icon"), _defineProperty__default.default(_defineProperty__default.default(_defineProperty__default.default({}, "".concat(iotPrefix, "--time-picker__icon--invalid"), invalidState), "".concat(iotPrefix, "--time-picker__icon--warn"), warnProp), "".concat(iotPrefix, "--time-picker__icon--readonl"), readOnly))
    }, /*#__PURE__*/React__default.default.createElement(inputState.firstIcon, {
      "aria-hidden": "true",
      focusable: false
    }))), /*#__PURE__*/React__default.default.createElement("p", {
      "data-testid": "".concat(testId, "-helpertext"),
      className: classnames__default.default("".concat(prefix, "--form__helper-text"), _defineProperty__default.default(_defineProperty__default.default(_defineProperty__default.default({}, "".concat(iotPrefix, "--time-picker__helper-text"), invalidState), "".concat(prefix, "--form__helper-text--disabled"), disabled), "".concat(iotPrefix, "--time-picker--invalid"), inputState.state === 'invalid'))
    }, !readOnly && invalidState ? invalidText : !readOnly && warnProp ? warnText : helperText)) : /*#__PURE__*/React__default.default.createElement("fieldset", null, hideSecondaryLabel && !hideLabel ? /*#__PURE__*/React__default.default.createElement("legend", {
      id: "".concat(id, "-label"),
      className: classnames__default.default("".concat(prefix, "--label"), _defineProperty__default.default({}, "".concat(prefix, "--label--disabled"), disabled))
    }, labelText) : null, /*#__PURE__*/React__default.default.createElement("div", {
      className: classnames__default.default("".concat(iotPrefix, "--time-picker__wrapper ").concat(iotPrefix, "--time-picker__wrapper-").concat(size), _defineProperty__default.default(_defineProperty__default.default({}, "".concat(iotPrefix, "--time-picker__wrapper--selected"), focusedInput === 0 && openState), "".concat(iotPrefix, "--time-picker--invalid"), inputState.state === 'invalid'))
    }, /*#__PURE__*/React__default.default.createElement(react.TextInput, {
      onChange: handleOnChange,
      "data-testid": "".concat(testId, "-input-1"),
      onFocus: function onFocus() {
        return handleOnFocus(0);
      },
      id: "".concat(id, "-1"),
      readOnly: readOnly,
      value: valueState,
      hideLabel: hideSecondaryLabel || hideLabel,
      "aria-labelledby": hideSecondaryLabel ? "".concat(id, "-label") : undefined,
      className: "".concat(iotPrefix, "--time-picker-range__text-input-wrapper"),
      labelText: !hideSecondaryLabel ? labelText : '',
      placeholder: is24hours ? placeholderText24h : placeholderText,
      size: size,
      warn: warnProp,
      invalid: invalidState,
      light: light,
      disabled: disabled,
      ref: inputRef
    }), /*#__PURE__*/React__default.default.createElement("div", {
      "data-testid": "".concat(testId, "-time-btn-1"),
      title: readOnly ? readOnlyBtnText : timeIconText,
      className: classnames__default.default("".concat(iotPrefix, "--time-picker__icon"), _defineProperty__default.default(_defineProperty__default.default(_defineProperty__default.default({}, "".concat(iotPrefix, "--time-picker__icon--invalid"), invalidState), "".concat(iotPrefix, "--time-picker__icon--warn"), warnProp), "".concat(iotPrefix, "--time-picker__icon--readonl"), readOnly))
    }, /*#__PURE__*/React__default.default.createElement(inputState.firstIcon, {
      "aria-hidden": "true",
      focusable: false
    }))), /*#__PURE__*/React__default.default.createElement("div", {
      className: classnames__default.default("".concat(iotPrefix, "--time-picker__wrapper ").concat(iotPrefix, "--time-picker__wrapper-").concat(size), _defineProperty__default.default(_defineProperty__default.default({}, "".concat(iotPrefix, "--time-picker__wrapper--selected"), focusedInput === 1 && openState), "".concat(iotPrefix, "--time-picker--invalid"), inputState.secondaryState === 'invalid'))
    }, /*#__PURE__*/React__default.default.createElement(react.TextInput, {
      "data-testid": "".concat(testId, "-input-2"),
      id: "".concat(id, "-2"),
      onChange: handleOnChange,
      onFocus: function onFocus() {
        return handleOnFocus(1);
      },
      readOnly: readOnly,
      value: secondaryValueState,
      hideLabel: hideSecondaryLabel || hideLabel,
      "aria-labelledby": hideSecondaryLabel ? "".concat(id, "-label") : undefined,
      className: "".concat(iotPrefix, "--time-picker-range__text-input-wrapper"),
      labelText: !hideSecondaryLabel ? secondaryLabelText : '',
      placeholder: is24hours ? placeholderText24h : placeholderText,
      size: size,
      warn: secondaryWarnProp,
      invalid: secondaryInvalidState,
      light: light,
      disabled: disabled,
      ref: secondaryInputRef
    }), /*#__PURE__*/React__default.default.createElement("div", {
      "data-testid": "".concat(testId, "-time-btn-2"),
      title: readOnly ? readOnlyBtnText : timeIconText,
      className: classnames__default.default("".concat(iotPrefix, "--time-picker__icon"), _defineProperty__default.default(_defineProperty__default.default(_defineProperty__default.default({}, "".concat(iotPrefix, "--time-picker__icon--invalid"), secondaryInvalidState), "".concat(iotPrefix, "--time-picker__icon--warn"), secondaryWarnProp), "".concat(iotPrefix, "--time-picker__icon--readonly"), readOnly))
    }, /*#__PURE__*/React__default.default.createElement(inputState.secondIcon, {
      "aria-hidden": "true",
      focusable: false
    }))), /*#__PURE__*/React__default.default.createElement("p", {
      "data-testid": "".concat(testId, "-range__helper-text"),
      className: classnames__default.default("".concat(prefix, "--form__helper-text"), "".concat(iotPrefix, "--time-picker-range__helper-text"), _defineProperty__default.default(_defineProperty__default.default({}, "".concat(prefix, "--form__helper-text--disabled"), disabled), "".concat(iotPrefix, "--time-picker--invalid"), inputState.state === 'invalid'))
    }, inputState.text), /*#__PURE__*/React__default.default.createElement("p", {
      "data-testid": "".concat(testId, "-range__helper-text--secondary"),
      className: classnames__default.default("".concat(prefix, "--form__helper-text"), "".concat(iotPrefix, "--time-picker-range__helper-text--secondary"), _defineProperty__default.default(_defineProperty__default.default({}, "".concat(prefix, "--form__helper-text--disabled"), disabled), "".concat(iotPrefix, "--time-picker--invalid"), inputState.secondaryState === 'invalid'))
    }, inputState.secondaryText)), openState ? /*#__PURE__*/React__default.default.createElement(TimePickerSpinner, {
      onChange: handleOnChange,
      focusedInput: focusedInput,
      value: focusedInput === 0 ? valueState : secondaryValueState,
      testId: "".concat(testId, "-spinner"),
      position: position,
      ref: dropDownRef,
      style: style,
      is24hours: is24hours,
      amString: amString,
      pmString: pmString
    }) : null)
  );
};
var listItemsForVertical24Hours = Array.from(Array(24)).map(function (el, i) {
  var index = i < 10 ? "0".concat(i) : "".concat(i);
  return {
    id: index,
    value: index
  };
});
var listItemsForVertical12Hours = listItemsForVertical24Hours.slice(1, 13);
var listItemsForVerticalMinutes = Array.from(Array(60)).map(function (el, i) {
  var index = i < 10 ? "0".concat(i) : "".concat(i);
  return {
    id: index,
    value: index
  };
});
var listItemsForVerticalMeridiem = function listItemsForVerticalMeridiem(amString, pmString) {
  return [{
    id: 'AM',
    value: amString
  }, {
    id: 'PM',
    value: pmString
  }];
};
var spinnerPropTypes = {
  position: PropTypes__default.default.arrayOf(PropTypes__default.default.number).isRequired,
  value: PropTypes__default.default.string,
  onChange: PropTypes__default.default.func,
  testId: PropTypes__default.default.string,
  style: PropTypes__default.default.objectOf(PropTypes__default.default.string),
  is24hours: PropTypes__default.default.bool,
  amString: PropTypes__default.default.string,
  pmString: PropTypes__default.default.string
};

/* istanbul ignore next */
var defaultSpinnerProps = {
  value: '',
  testId: 'time-picker-spinner',
  onChange: function onChange() {},
  style: {},
  is24hours: false,
  amString: 'AM',
  pmString: 'PM'
};
var TimePickerSpinner = /*#__PURE__*/React__default.default.forwardRef(function (_ref2, ref) {
  var onChange = _ref2.onChange,
    position = _ref2.position,
    value = _ref2.value,
    testId = _ref2.testId,
    style = _ref2.style,
    is24hours = _ref2.is24hours,
    amString = _ref2.amString,
    pmString = _ref2.pmString;
  var currentTime = dayjs__default.default().format(AVAILABLE_FORMATS);
  var updatedStyle = React.useMemo(function () {
    var _style$zIndex;
    return _objectSpread(_objectSpread({}, style), {}, {
      '--zIndex': (_style$zIndex = style.zIndex) !== null && _style$zIndex !== void 0 ? _style$zIndex : 0
    });
  }, [style]);
  var firstVal = React.useMemo(function () {
    return is24hours ? timeUtils.get24Hours(value, currentTime) : timeUtils.get12Hours(value, currentTime);
  }, [value, is24hours, currentTime]);
  var secondVal = React.useMemo(function () {
    return timeUtils.getMinutes(value, currentTime);
  }, [value, currentTime]);
  var thirdVal = React.useMemo(function () {
    return is24hours ? '' : timeUtils.getMeridiem(value, currentTime, amString, pmString) === amString ? 'AM' : 'PM';
  }, [is24hours, value, currentTime, amString, pmString]);
  var _useState15 = React.useState([firstVal, secondVal, thirdVal]),
    _useState16 = _slicedToArray__default.default(_useState15, 2),
    selected = _useState16[0],
    setSelected = _useState16[1];
  var _useState17 = React.useState(value),
    _useState18 = _slicedToArray__default.default(_useState17, 2),
    callbackValue = _useState18[0],
    setCallbackValue = _useState18[1];
  var _useState19 = React.useState(0),
    _useState20 = _slicedToArray__default.default(_useState19, 2),
    setFocusedSpinner = _useState20[1];
  var secondSpinnerRef = React.useRef();
  var thirdSpinnerRef = React.useRef();
  var numberOfSpinners = is24hours ? 2 : 3;
  React.useEffect(function () {
    setSelected([firstVal, secondVal, thirdVal]);
  }, [firstVal, secondVal, thirdVal]);
  React.useEffect(function () {
    onChange(callbackValue);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [callbackValue]);
  var handleOnClick = function handleOnClick(str, index) {
    setSelected(function (prev) {
      var arr = _toConsumableArray__default.default(prev);
      arr[index] = str;
      var newValue = is24hours ? "".concat(arr[0], ":").concat(arr[1]) : "".concat(arr[0], ":").concat(arr[1], " ").concat(arr[2]);
      setCallbackValue(newValue);
      return arr;
    });
  };

  /* eslint-disable no-unused-expressions */
  var handleRightArrowClick = React.useCallback(function () {
    setFocusedSpinner(function (prevValue) {
      var nextSelected = (prevValue + 1) % numberOfSpinners;
      if (nextSelected === 0) {
        ref === null || ref === void 0 || ref.current.focus();
      }
      if (nextSelected === 1) {
        secondSpinnerRef === null || secondSpinnerRef === void 0 || secondSpinnerRef.current.focus();
      }
      if (nextSelected === 2) {
        thirdSpinnerRef === null || thirdSpinnerRef === void 0 || thirdSpinnerRef.current.focus();
      }
      return nextSelected;
    });
  }, [numberOfSpinners, ref]);
  var handleLeftArrowClick = React.useCallback(function () {
    var stepBehind = is24hours ? 1 : 2;
    setFocusedSpinner(function (prevValue) {
      var nextSelected = (prevValue + stepBehind) % numberOfSpinners;
      if (nextSelected === 0) {
        ref === null || ref === void 0 || ref.current.focus();
      }
      if (nextSelected === 1) {
        secondSpinnerRef === null || secondSpinnerRef === void 0 || secondSpinnerRef.current.focus();
      }
      if (nextSelected === 2) {
        thirdSpinnerRef === null || thirdSpinnerRef === void 0 || thirdSpinnerRef.current.focus();
      }
      return nextSelected;
    });
  }, [is24hours, numberOfSpinners, ref]);
  /* eslint-enable no-unused-expressions */

  var listSpinner1 = React.useMemo(function () {
    return /*#__PURE__*/React__default.default.createElement(ListSpinner.default, {
      testId: "".concat(testId, "-list-spinner-1"),
      ref: ref,
      onClick: function onClick(e) {
        return handleOnClick(e, 0);
      },
      list: is24hours ? listItemsForVertical24Hours : listItemsForVertical12Hours,
      defaultSelectedId: selected[0],
      onRightArrowClick: handleRightArrowClick,
      onLeftArrowClick: handleLeftArrowClick
    });
  }, /* eslint-disable-next-line react-hooks/exhaustive-deps */
  [selected[0]]);
  var listSpinner2 = React.useMemo(function () {
    return /*#__PURE__*/React__default.default.createElement(ListSpinner.default, {
      testId: "".concat(testId, "-list-spinner-2"),
      ref: secondSpinnerRef,
      onClick: function onClick(e) {
        return handleOnClick(e, 1);
      },
      list: listItemsForVerticalMinutes,
      defaultSelectedId: selected[1],
      onRightArrowClick: handleRightArrowClick,
      onLeftArrowClick: handleLeftArrowClick
    });
  }, /* eslint-disable-next-line react-hooks/exhaustive-deps */
  [selected[1]]);
  var listSpinner3 = React.useMemo(function () {
    return /*#__PURE__*/React__default.default.createElement(ListSpinner.default, {
      testId: "".concat(testId, "-list-spinner-3"),
      ref: thirdSpinnerRef,
      className: classnames__default.default("".concat(iotPrefix, "--time-picker-spinner-last-list-spinner"), _defineProperty__default.default({}, "".concat(iotPrefix, "--time-picker-spinner-last-list-spinner--PM"), selected[2] === pmString)),
      onClick: function onClick(e) {
        return handleOnClick(e, 2);
      },
      list: listItemsForVerticalMeridiem(amString, pmString),
      defaultSelectedId: selected[2],
      onRightArrowClick: handleRightArrowClick,
      onLeftArrowClick: handleLeftArrowClick
    });
  }, /* eslint-disable-next-line react-hooks/exhaustive-deps */
  [selected[2]]);
  var dropdown = /*#__PURE__*/React__default.default.createElement("div", {
    "data-testid": testId,
    className: classnames__default.default("".concat(iotPrefix, "--time-picker-spinner"), _defineProperty__default.default({}, "".concat(iotPrefix, "--time-picker-spinner--24h"), is24hours)),
    style: _objectSpread(_objectSpread({}, updatedStyle), {}, {
      left: "".concat(position[0], "px"),
      top: "".concat(position[1], "px")
    })
  }, listSpinner1, listSpinner2, is24hours ? null : listSpinner3);
  return /*#__PURE__*/ReactDOM__default.default.createPortal(dropdown, document.body);
});
TimePickerSpinner.propTypes = spinnerPropTypes;
TimePickerSpinner.defaultProps = defaultSpinnerProps;
TimePickerDropdown.propTypes = propTypes;
TimePickerDropdown.defaultProps = defaultProps;
TimePickerDropdown.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "TimePickerDropdown",
  "props": {
    "className": {
      "defaultValue": {
        "value": "undefined",
        "computed": true
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "hideLabel": {
      "defaultValue": {
        "value": "false",
        "computed": false
      },
      "description": "Specify whether the input labels to be visually hidden",
      "type": {
        "name": "bool"
      },
      "required": false
    },
    "value": {
      "defaultValue": {
        "value": "undefined",
        "computed": true
      },
      "description": "Specify the value for input",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "secondaryValue": {
      "defaultValue": {
        "value": "undefined",
        "computed": true
      },
      "description": "Specify the value for secondary input (range)",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "hideSecondaryLabel": {
      "defaultValue": {
        "value": "false",
        "computed": false
      },
      "description": "Specify whether the secondary label to be visually hidden",
      "type": {
        "name": "bool"
      },
      "required": false
    },
    "type": {
      "defaultValue": {
        "value": "'single'",
        "computed": false
      },
      "description": "Input can be for a single time or a range - defaults to single",
      "type": {
        "name": "enum",
        "value": [{
          "value": "'single'",
          "computed": false
        }, {
          "value": "'range'",
          "computed": false
        }]
      },
      "required": false
    },
    "i18n": {
      "defaultValue": {
        "value": "{\n  invalidText: 'The time entered is invalid',\n  warnText: undefined,\n  timeIconText: 'Open time picker',\n  placeholderText: 'hh:mm XM',\n  placeholderText24h: 'HH:mm',\n  readOnlyBtnText: 'Read only',\n  amString: 'AM',\n  pmString: 'PM',\n}",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "shape",
        "value": {
          "labelText": {
            "name": "string",
            "description": "Label for input (will be first, if range type)",
            "required": true
          },
          "helperText": {
            "name": "string",
            "required": false
          },
          "secondaryLabelText": {
            "name": "string",
            "description": "Label for second input in range",
            "required": false
          },
          "secondaryHelperText": {
            "name": "string",
            "required": false
          },
          "invalidText": {
            "name": "string",
            "required": false
          },
          "warnText": {
            "name": "string",
            "required": false
          },
          "timeIconText": {
            "name": "string",
            "required": false
          },
          "placeholderText": {
            "name": "string",
            "required": false
          },
          "placeholderText24h": {
            "name": "string",
            "required": false
          },
          "amString": {
            "name": "string",
            "required": false
          },
          "pmString": {
            "name": "string",
            "required": false
          }
        }
      },
      "required": false
    },
    "size": {
      "defaultValue": {
        "value": "'md'",
        "computed": false
      },
      "description": "Size of input",
      "type": {
        "name": "enum",
        "value": [{
          "value": "'sm'",
          "computed": false
        }, {
          "value": "'md'",
          "computed": false
        }, {
          "value": "'lg'",
          "computed": false
        }]
      },
      "required": false
    },
    "disabled": {
      "defaultValue": {
        "value": "false",
        "computed": false
      },
      "description": "Specify whether the control is currently disabled",
      "type": {
        "name": "bool"
      },
      "required": false
    },
    "readOnly": {
      "defaultValue": {
        "value": "false",
        "computed": false
      },
      "description": "Specify whether the control is currently read only",
      "type": {
        "name": "bool"
      },
      "required": false
    },
    "warn": {
      "defaultValue": {
        "value": "[false, false]",
        "computed": false
      },
      "description": "Specify whether the control is currently in warning state",
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "bool"
        }
      },
      "required": false
    },
    "invalid": {
      "defaultValue": {
        "value": "[false, false]",
        "computed": false
      },
      "description": "Specify whether the control is currently in invalid state",
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "bool"
        }
      },
      "required": false
    },
    "light": {
      "defaultValue": {
        "value": "false",
        "computed": false
      },
      "description": "Boolean to swap for light theme",
      "type": {
        "name": "bool"
      },
      "required": false
    },
    "onChange": {
      "defaultValue": {
        "value": "() => {}",
        "computed": false
      },
      "description": "Optional handler that is called whenever <input> is updated - will be called with new value as an argument",
      "type": {
        "name": "func"
      },
      "required": false
    },
    "testId": {
      "defaultValue": {
        "value": "'time-picker'",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "style": {
      "defaultValue": {
        "value": "{}",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "objectOf",
        "value": {
          "name": "union",
          "value": [{
            "name": "string"
          }, {
            "name": "number"
          }]
        }
      },
      "required": false
    },
    "is24hours": {
      "defaultValue": {
        "value": "false",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "bool"
      },
      "required": false
    },
    "id": {
      "description": "",
      "type": {
        "name": "string"
      },
      "required": true
    }
  }
};
var TimePickerDropdown$1 = TimePickerDropdown;
TimePickerSpinner.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "TimePickerSpinner",
  "props": {
    "value": {
      "defaultValue": {
        "value": "''",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "testId": {
      "defaultValue": {
        "value": "'time-picker-spinner'",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "onChange": {
      "defaultValue": {
        "value": "() => {}",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "func"
      },
      "required": false
    },
    "style": {
      "defaultValue": {
        "value": "{}",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "objectOf",
        "value": {
          "name": "string"
        }
      },
      "required": false
    },
    "is24hours": {
      "defaultValue": {
        "value": "false",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "bool"
      },
      "required": false
    },
    "amString": {
      "defaultValue": {
        "value": "'AM'",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "pmString": {
      "defaultValue": {
        "value": "'PM'",
        "computed": false
      },
      "description": "",
      "type": {
        "name": "string"
      },
      "required": false
    },
    "position": {
      "description": "",
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "number"
        }
      },
      "required": true
    }
  }
};

exports.TimePickerSpinner = TimePickerSpinner;
exports.default = TimePickerDropdown$1;
